import type { AppRouteModule } from '@/router/types';

import { LAYOUT } from '@/router/constant';

const engineeringProject: AppRouteModule = {
  path: '/engineeringProject',
  name: 'engineeringProject',
  component: LAYOUT,
  redirect: '/engineeringProject/index',
  meta: {
    hideChildrenInMenu: false,
    icon: 'icon-park-outline:align-text-left-one',
    orderNo: 8,
    auth: '/www/dist/index.html#/engineeringProject/index',
    title: '年度投资及资金计划管理',
  },
  children: [
    {
      path: 'index',
      name: 'engineeringProject',
      component: () => import('@/views/engineeringProject/index.vue'),
      meta: {
        auth: '/www/dist/index.html#/engineeringProject/index',
        title: '工程项目投资计划填报',
        orderNo: 1,
      },
    },
    {
      path: 'statisticEngineering',
      name: 'statisticEngineering',
      component: () => import('@/views/engineeringProject/statisticEngineering/index.vue'),
      meta: {
        auth: '/www/dist/index.html#/engineeringProject/index',
        title: '工程项目投资计划统计',
        orderNo: 1,
      },
    },
    {
      path: 'engineeringEdit',
      name: 'engineeringEdit',
      component: () => import('@/views/engineeringProject/engineeringEdit/engineeringEdit.vue'),
      meta: {
        hideMenu: true,
        auth: '/www/dist/index.html#/engineeringProject/index',
        title: '新建计划',
        orderNo: 1,
      },
    },
    {
      path: 'constructionEdit',
      name: 'constructionEdit',
      component: () => import('@/views/engineeringProject/constructionEdit/constructionEdit.vue'),
      meta: {
        hideTab: true,
        hideMenu: true,
        hideBreadcrumb: true,
        auth: '/www/dist/index.html#/engineeringProject/index',
        title: '新建计划（承建）',
        orderNo: 1,
      },
    },
    {
      path: 'reserveEdit',
      name: 'reserveEdit',
      component: () => import('@/views/engineeringProject/reserveEdit/reserveEdit.vue'),
      meta: {
        hideTab: true,
        hideMenu: true,
        hideBreadcrumb: true,
        auth: '/www/dist/index.html#/engineeringProject/index',
        title: '新建计划（储备）',
        orderNo: 1,
      },
    },
    {
      path: 'performance',
      name: 'performance',
      component: () => import('@/views/performance/index.vue'),
      meta: {
        auth: '/www/dist/index.html#/performance/index',
        title: '投资计划完成情况填报',
        orderNo: 2,
      },
    },
    {
      path: 'statisticPerformance',
      name: 'statisticPerformance',
      component: () => import('@/views/performance/statisticPerformance/index.vue'),
      meta: {
        auth: '/www/dist/index.html#/performance/index',
        title: '投资计划完成情况统计',
        orderNo: 2,
      },
    },
    {
      path: 'performanceEdit',
      name: 'performanceEdit',
      component: () => import('@/views/performance/performanceEdit.vue'),
      meta: {
        hideTab: true,
        hideMenu: true,
        hideBreadcrumb: true,
        auth: '/www/dist/index.html#/performance/index',
        title: '项目投资计划完成情况',
        orderNo: 2,
      },
    },
    {
      path: 'annualPlan',
      name: 'annualPlan',
      component: () => import('@/views/annualPlan/index.vue'),
      meta: {
        hideTab: true,
        hideMenu: true,
        hideBreadcrumb: true,
        auth: '/www/dist/index.html#/annualPlan/index',
        title: '年度资金计划填报',
        orderNo: 3,
      },
    },
    {
      path: 'annualPlaEdit',
      name: 'annualPlanEdit',
      component: () => import('@/views/annualPlan/annualPlanEdit/annualPlanEdit.vue'),
      meta: {
        hideTab: true,
        hideMenu: true,
        hideBreadcrumb: true,
        auth: '/www/dist/index.html#/annualPlan/index',
        title: '新建年度资金计划',
        orderNo: 3,
      },
    },
    {
      path: 'completed',
      name: 'completed',
      component: () => import('@/views/completed/index.vue'),
      meta: {
        auth: '/www/dist/index.html#/completed/index',
        title: '年度工程资金计划填报',
        orderNo: 4,
      },
    },
    {
      path: 'completedEdit',
      name: 'completedEdit',
      component: () => import('@/views/completed/completedEdit/completedEdit.vue'),
      meta: {
        hideMenu: true,
        auth: '/www/dist/index.html#/completed/index',
        title: '新建年度工程资金计划',
        orderNo: 12,
      },
    },
    {
      path: 'completedData',
      name: 'completedData',
      component: () => import('@/views/completed/completedData.vue'),
      meta: {
        auth: '/www/dist/index.html#/completed/index',
        title: '年度工程资金计划统计',
        orderNo: 4,
      },
    },
  ],
};

export default engineeringProject;
