import { BasicColumn, FormSchema } from '@/components/Table';

import {useUserStore} from "@/store/modules/user";
const deptId = ''+useUserStore().userInfo.deptParentId;
//主模块-投资管理列表页
export const columns: BasicColumn[] = [
  {
    title: '序号',
    dataIndex: 'serialNumber',
    width: 100,
  },
  {
    title: '填报周期',
    dataIndex: 'tenderYear',
    width: 200,
  },
  {
    title: '项目数量',
    dataIndex: 'proNumber',
    width: 180,
  },
  {
    title: '公司名称',
    dataIndex: 'companyName',
    width: 180,
  },
  {
    title: '最新更新人',
    dataIndex: 'updateBy',
    width: 180,
  },
  {
    title: '审核人',
    dataIndex: 'revieweUser',
    width: 180,
  },
  {
    title: '审核时间',
    dataIndex: 'reviewTime',
    width: 180,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'tenderYear',
    label: '',
    component: 'DatePicker',
    componentProps: {
      placeholder: '年份',
      picker: 'year',
      valueFormat: 'YYYY',
      format: 'YYYY',
      style: {
        width: '100%',
      },
    },
    colProps: { span: 4 },
  },
  {
    field: 'biddingQuarter',
    label: '',
    component: 'Select',
    componentProps: {
      placeholder: '季度',
      options: [
        {
          label: '第一季度',
          value: '第一季度',
        },
        {
          label: '第二季度',
          value: '第二季度',
        },
        {
          label: '第三季度',
          value: '第三季度',
        },
        {
          label: '第四季度',
          value: '第四季度',
        },
      ],
    },
    colProps: { span: 4 },
  },
  {
    field: 'companyId',
    label: '',
    component: 'Select',
    ifShow: deptId === '100',
    componentProps: {
      // options: getDepartment(),
      options: [
        { label: '公司名称1', value: '1' },
        { label: '公司名称2', value: '0' },
      ],
      placeholder: '公司名称',
    },
    colProps: { span: 4 },
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'projectName',
    label: '项目名称',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },

  {
    field: 'fundingSource',
    label: '资金来源',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'investmentAmount',
    label: '立项投资额',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'field11',
    component: 'BasicTitle',
    label: '招标方案',
    componentProps: {
      // line: true,
      span: true,
    },
    colProps: {
      span: 24,
    },
  },
  {
    field: 'biddingType',
    label: '招标类型(施工、监理、设计、图审等)',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
    labelWidth: 400,
  },
  {
    field: 'tenderContent',
    label: '招标内容',
    required: true,
    component: 'InputTextArea',
    componentProps: {
      maxlength: 100,
      showCount: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'controlPrice',
    label: '招标控制价',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'constructionMode',
    label: '建设模式',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
    componentProps: {
      readonly: true,
      disabled: true,
    },
  },
  {
    field: 'biddingAgency',
    label: '招标代理',
    required: false,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'procurementMethod',
    label: '招标采购方式',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '建委招标',
          value: '建委招标',
        },
        {
          label: '平台招标',
          value: '平台招标',
        },
        {
          label: '邀标比选',
          value: '邀标比选',
        },
        {
          label: '直接委托',
          value: '直接委托',
        },
        {
          label: '评定分离',
          value: '评定分离',
        },
      ],
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    label: '评标办法',
    field: 'evaluationMethod',
    required: false,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'field11',
    component: 'BasicTitle',
    label: '招标结果及完成情况汇总',
    componentProps: {
      // line: true,
      span: true,
    },
    colProps: {
      span: 24,
    },
  },
  {
    label: '招标完成情况',
    field: 'completionStatus',
    required: true,
    component: 'InputTextArea',
    componentProps: {
      maxlength: 100,
      showCount: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    label: '开标时间',
    field: 'openingTime',
    required: true,
    component: 'InputTextArea',
    componentProps: {
      maxlength: 100,
      showCount: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'winningBidder',
    label: '中标单位',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'winningAmount',
    label: '中标金额',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '元',
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'winningPeriod',
    label: '中标工期',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'signingDate',
    label: '合同签订日期',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    label: '会议纪要',
    field: 'meetingMinute',
    required: true,
    component: 'InputTextArea',
    componentProps: {
      maxlength: 100,
      showCount: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'releaseChannels',
    label: '招标信息发布渠道',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '中国招标投标公共服务平台',
          value: '中国招标投标公共服务平台',
        },
        {
          label: '公司OA和公众号',
          value: '公司OA和公众号',
        },
        {
          label: '天津市公共资源交易中心',
          value: '天津市公共资源交易中心',
        },
        {
          label: '邮箱',
          value: '邮箱',
        },
        {
          label: '其他',
          value: '其他',
        },
      ],
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'detailedInformation',
    label: '招标信息发布渠道-其他（详细填写）',
    required: false,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'publishWebsite',
    label: '招标公告发布网址（仅限公开招标项目）',
    required: false,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'publicityWebsite',
    label: '中标结果公示网址（仅限公开招标项目）',
    required: false,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'isReportingSituation',
    label: '是否存在投诉举报情况',
    required: true,
    component: 'Select',
    componentProps: {
      style: {
        width: '100%',
      },
      options: [
        {
          label: '是',
          value: '是',
        },
        {
          label: '否',
          value: '否',
        },
      ],
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    label: '投诉举报解决处理情况',
    field: 'handSituation',
    required: false,
    component: 'InputTextArea',
    componentProps: {
      maxlength: 100,
      showCount: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    label: '备注',
    field: 'remark',
    // required: true,
    component: 'InputTextArea',
    componentProps: {
      maxlength: 100,
      showCount: true,
    },
    colProps: { span: 7, offset: 1 },
  },
];
