import { BasicColumn, FormSchema } from '@/components/Table';
import {useUserStore} from "@/store/modules/user";
//主模块-变更签名列表页

const deptId = ''+useUserStore().userInfo.deptParentId;
export const columns: BasicColumn[] = [
  {
    title: '填报周期',
    dataIndex: 'yearQuarter',
    width: 200,
  },
  {
    title: '项目数量',
    dataIndex: 'uniqueProjectCount',
    width: 180,
  },
  {
    title: '公司名称',
    dataIndex: 'companyName',
    width: 180,
  },
  {
    title: '最新更新人',
    dataIndex: 'updateBy',
    width: 180,
  },
  {
    title: '最新更新时间',
    dataIndex: 'updateTime',
    width: 180,
  },
  {
    title: '审核状态',
    dataIndex: 'status',
    ifShow: deptId !== '100',
    width: 180,
  },
  {
    title: '审核人',
    dataIndex: 'auditor',
    width: 180,
  },
  {
    title: '审核时间',
    dataIndex: 'auditTime',
    width: 180,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'givenYear',
    label: '',
    component: 'DatePicker',
    componentProps: {
      placeholder: '年份',
      picker: 'year',
      style: { width: '100%' },
      valueFormat: 'YYYY',
      format: 'YYYY',
    },
    colProps: { span: 4 },
  },
  {
    field: 'quarter',
    label: '',
    component: 'Select',
    componentProps: {
      options: [
        { label: '第一季度', value: '第一季度' },
        { label: '第二季度', value: '第二季度' },
        {
          label: '第三季度',
          value: '第三季度',
        },
        {
          label: '第四季度',
          value: '第四季度',
        },
      ],
      placeholder: '季度',
    },
    colProps: { span: 4 },
  },
  {
    field: 'companyId',
    label: '',
    component: 'Select',
    required: false,
    componentProps: {
      options: [
        { label: '公司名称1', value: '1' },
        { label: '公司名称2', value: '0' },
      ],
      placeholder: '公司名称',
    },
    ifShow: deptId === '100',
    colProps: { span: 4 },
  },
];
// 前半部分
export const formSchema: FormSchema[] = [
  {
    field: 'projectName',
    label: '项目名称',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
      style: { border: 'none' },
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'fundingSource',
    label: '资金来源',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
      style: { border: 'none' },
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'amountInvested',
    label: '立项投资额',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
    colProps: { span: 7, offset: 1 },
  },
];
// 后半部分
export const subFormSchema: FormSchema[] = [
  {
    field: 'contractName',
    label: ' 合同名称',
    required: false,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
      style: { border: 'none' },
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'biddingMethod',
    label: '招标方式',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        { label: '建委招标', value: '建委招标' },
        { label: '平台招标', value: '平台招标' },
        { label: '邀标比选', value: '邀标比选' },
        { label: '直接委托', value: '直接委托' },
        { label: '评定分离', value: '评定分离' },
      ],
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'contractType',
    label: '合同类型(施工、监理、设计、图审等)',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'firstPartyName',
    label: '甲方单位名称',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'partyName',
    label: '乙方单位名称',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'responsibleParty',
    label: '责任方',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'formOfContract',
    label: '合同形式',
    required: true,
    component: 'Select',
    componentProps: ({ formActionType }) => ({
      options: [
        {
          label: '固定总价',
          value: '固定总价',
        },
        {
          label: '固定单价',
          value: '固定单价',
        },
        {
          label: '费率',
          value: '费率',
        },
        {
          label: '其他',
          value: '其他',
        },
      ],
      onChange: (value) => {
        if (value === '其他') {
          formActionType.updateSchema([
            { field: 'forOfContractOther', required: true, ifShow: true },
          ]);
        } else {
          formActionType.updateSchema([
            { field: 'forOfContractOther', required: false, ifShow: false },
          ]);
        }
      },
    }),
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'forOfContractOther',
    label: '合同形式(其他情况)',
    ifShow: false,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'contractAmount',
    label: '合同金额',
    required: true,
    component: 'InputNumber',
    componentProps: ({ formModel, formActionType }) => ({
      addonAfter: '万元',
      readonly: true,
      disabled: true,
      onChange: (value) => {
        formModel.contractAmount = value;
        updateAmountRatio(formModel, formActionType);
        updateContractValueRatio(formModel, formActionType);
        updateEstimatedAmountRatio(formModel, formActionType);
      },
    }),
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'changeAmount',
    label: '合同累计签证、变更金额（含本次）:',
    labelWidth: '300px',
    required: true,
    component: 'InputNumber',
    componentProps: ({ formModel, formActionType }) => ({
      addonAfter: '元',
      onChange: (value) => {
        formModel.changeAmount = value;
        updateAmountRatio(formModel, formActionType);
      },
    }),
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'amountRatio',
    label: '累计变更签证金额占合同金额比例:',
    labelWidth: '300px',
    component: 'InputNumber',
    componentProps: {
      addonAfter: '%',
      readonly: true,
      disabled: true,
      precision: 2, // 设置小数点后两位
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'changeNumber',
    label: '变更编号',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'changeType',
    label: '变更类型:',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'changeContent',
    label: ' 变更内容:',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'updateAmount',
    label: '预估变更金额:',
    required: true,
    component: 'InputNumber',
    componentProps: ({ formModel, formActionType }) => ({
      addonAfter: '元',
      onChange: (value) => {
        formModel.updateAmount = value;
        updateContractValueRatio(formModel, formActionType);
      },
    }),
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'contractValueRatio',
    label: '预估变更金额占合同金额比例:',
    labelWidth: '300px',
    component: 'Input',
    componentProps: {
      addonAfter: '%',
      readonly: true,
      disabled: true,
      precision: 2, // 设置小数点后两位
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'visaNumber',
    label: '签证编号:',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'visaType',
    label: '签证类型:',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'visaContent',
    label: '签证内容:',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'visaAmount',
    label: '预估签证金额:',
    required: true,
    component: 'InputNumber',
    componentProps: ({ formModel, formActionType }) => ({
      addonAfter: '元',
      onChange: (value) => {
        formModel.visaAmount = value;
        updateEstimatedAmountRatio(formModel, formActionType);
      },
    }),
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'estimatedAmountRatio',
    label: '预估签证金额占合同金额比例:',
    labelWidth: '300px',
    component: 'InputNumber',
    componentProps: {
      addonAfter: '%',
      readonly: true,
      disabled: true,
      precision: 2, // 设置小数点后两位
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'meetingMinutes',
    label: '会议纪要',
    required: true,
    component: 'InputTextArea',
    componentProps: {
      maxlength: 100,
      showCount: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'remark',
    label: '备注',
    component: 'InputTextArea',
    componentProps: {
      maxlength: 100,
      showCount: true,
    },
    colProps: { span: 7, offset: 1 },
  },
];

// 辅助函数用于更新 amountRatio
function updateAmountRatio(formModel, formActionType) {
  const { contractAmount, changeAmount } = formModel;

  if (contractAmount && changeAmount) {
    const ratio = (parseFloat(changeAmount) / parseFloat(contractAmount * 10000)) * 100;
    formModel.amountRatio = ratio.toFixed(2); // 将比例保留两位小数
  } else {
    formModel.amountRatio = null; // 如果任何一个为空，则清空比例
  }

  // 触发表单更新
  formActionType.setFieldsValue({ amountRatio: formModel.amountRatio });
}
// 辅助函数用于更新 contractValueRatio
function updateContractValueRatio(formModel, formActionType) {
  const { contractAmount, updateAmount } = formModel;

  if (contractAmount && updateAmount) {
    const ratio = (parseFloat(updateAmount) / parseFloat(contractAmount * 10000)) * 100;
    formModel.contractValueRatio = ratio.toFixed(2); // 将比例保留两位小数
  } else {
    formModel.contractValueRatio = null; // 如果任何一个为空，则清空比例
  }

  // 触发表单更新
  formActionType.setFieldsValue({ contractValueRatio: formModel.contractValueRatio });
}
// 辅助函数用于更新 estimatedAmountRatio
function updateEstimatedAmountRatio(formModel, formActionType) {
  const { contractAmount, visaAmount } = formModel;

  if (contractAmount && visaAmount) {
    const ratio = (parseFloat(visaAmount) / parseFloat(contractAmount * 10000)) * 100;
    formModel.estimatedAmountRatio = ratio.toFixed(2); // 将比例保留两位小数
  } else {
    formModel.estimatedAmountRatio = null; // 如果任何一个为空，则清空比例
  }

  // 触发表单更新
  formActionType.setFieldsValue({ estimatedAmountRatio: formModel.estimatedAmountRatio });
}
