import { FormSchema, BasicColumn } from '@/components/Table';

export function getBasicColumns(): BasicColumn[] {
  return [
    {
      title: '季度',
      dataIndex: 'quarter',
      width: 80,
    },
    {
      title: '数值(万元)',
      dataIndex: 'value',
      width: 80,
      edit: true,
      editable: true,
      editRule: true,
      editComponent: 'InputNumber',
    },
  ];
}

export function basicColumnsDisabled(): BasicColumn[] {
  return [
    {
      title: '季度',
      dataIndex: 'quarter',
      width: 80,
    },
    {
      title: '数值(万元)',
      dataIndex: 'value',
      width: 80,
      editComponent: 'InputNumber',
    },
  ];
}

export function getBasicColumnsTwo(): BasicColumn[] {
  return [
    {
      title: '季度',
      dataIndex: 'quarter',
      width: 50,
      fixed: 'left',
    },
    {
      title: '政府拨款(万元)',
      dataIndex: 'governmentGrant',
      width: 50,
      edit: true,
      editable: true,
      editRule: true,
      editComponent: 'InputNumber',
    },
    {
      title: '专项债拨款(万元)',
      dataIndex: 'specialBond',
      width: 50,
      edit: true,
      editable: true,
      editRule: true,
      editComponent: 'InputNumber',
    },
    {
      title: '银行融资(万元)',
      dataIndex: 'bankFinancing',
      width: 50,
      edit: true,
      editable: true,
      editRule: true,
      editComponent: 'InputNumber',
    },
    {
      title: '自有资金(万元)',
      dataIndex: 'ownFunds',
      width: 50,
      edit: true,
      editable: true,
      editRule: true,
      editComponent: 'InputNumber',
    },
    {
      title: '资金缺口(万元)',
      dataIndex: 'fundingGap',
      width: 50,
      edit: true,
      editable: true,
      editRule: true,
      editComponent: 'InputNumber',
    },
    {
      title: '资金计划额(万元)',
      dataIndex: 'totalValue',
      width: 50,
      customRender: ({ record }) => {
        // 这里可以根据record的其他字段计算值
        record.totalValue = (
          Number(record.ownFunds) +
          Number(record.specialBond) +
          Number(record.bankFinancing) +
          Number(record.governmentGrant) +
          Number(record.fundingGap)
        ).toFixed(2); // 计算新值
        return record.totalValue; // 返回计算后的值
      },
    },
  ];
}

export function basicColumnsTwoDisabled(): BasicColumn[] {
  return [
    {
      title: '季度',
      dataIndex: 'quarter',
      width: 80,
    },
    {
      title: '政府拨款',
      dataIndex: 'governmentGrant',
      width: 150,
      editComponent: 'InputNumber',
    },
    {
      title: '专项债拨款',
      dataIndex: 'specialBond',
      width: 150,
      editComponent: 'InputNumber',
    },
    {
      title: '银行融资',
      dataIndex: 'bankFinancing',
      width: 150,
      editComponent: 'InputNumber',
    },
    {
      title: '自有资金',
      dataIndex: 'ownFunds',
      width: 150,
      editComponent: 'InputNumber',
    },
    {
      title: '资金缺口(万元)',
      dataIndex: 'fundingGap',
      width: 50,
      editComponent: 'InputNumber',
    },
    {
      title: '资金计划额(万元)',
      dataIndex: 'totalValue',
      width: 50,
      editComponent: 'InputNumber',
    },
  ];
}

export function formSchema(year, planType): FormSchema[] {
  return [
    {
      field: 'projectName',
      label: '项目名称',
      required: true,
      component: 'Input',
      componentProps: {
        readonly: true,
        disabled: true,
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'constructionSite',
      label: '建设地点',
      required: true,
      component: 'Input',
      componentProps: {
        readonly: true,
        disabled: true,
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'projectType',
      label: '项目类型:',
      required: true,
      component: 'Input',
      componentProps: {
        readonly: true,
        disabled: true,
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'annualFund',
      label: parseInt(year) - 1 + '年资金执行情况-计划额:',
      labelWidth: 200,
      required: true,
      component: 'InputNumber',
      componentProps: {
        addonAfter: '万元',
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'actualPay',
      label: parseInt(year) - 1 + '年资金执行情况-实付额',
      labelWidth: 200,
      required: true,
      component: 'InputNumber',
      componentProps: {
        addonAfter: '万元',
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'totalActualPay',
      label: parseInt(year) - 1 + '年底前累计实付额',
      labelWidth: 200,
      required: true,
      component: 'InputNumber',
      componentProps: {
        addonAfter: '万元',
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'projectInvestment',
      label: '立项总投资',
      required: true,
      component: 'InputNumber',
      componentProps: {
        addonAfter: '万元',
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'completionSettlement',
      label: '竣工结算额',
      required: false,
      show: planType === '已竣工验收项目' ? true : false,
      component: 'InputNumber',
      componentProps: {
        addonAfter: '万元',
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'contractAmount',
      label: '合同额',
      required: planType === '已竣工验收项目' ? true : false,
      show: planType === '已竣工验收项目' ? true : false,
      component: 'InputNumber',
      componentProps: {
        addonAfter: '万元',
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'plannedInvestment',
      label: parseInt(year) + '年计划投资',
      labelWidth: 200,
      required: planType === '计划投资项目' ? true : false,
      show: planType === '计划投资项目' ? true : false,
      component: 'InputNumber',
      componentProps: {
        addonAfter: '万元',
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'constructionNature',
      label: '建设性质',
      required: planType === '计划投资项目' ? true : false,
      show: planType === '计划投资项目' ? true : false,
      component: 'Select',
      componentProps: {
        options: [
          { label: '新建', value: '新建' },
          { label: '结转', value: '结转' },
          { label: '缓建', value: '缓建' },
        ],
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'fundSource',
      label: '资金来源',
      required: true,
      component: 'Select',
      componentProps: {
        options: [
          { label: '政府投资项目', value: '政府投资项目' },
          { label: '公司投资项目', value: '公司投资项目' },
          { label: '专项债项目', value: '专项债项目' },
          { label: '承建项目', value: '承建项目' },
        ],
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'time',
      component: 'RangePicker',
      label: '开竣工时间',
      required: planType === '计划投资项目' ? true : false,
      show: planType === '计划投资项目' ? true : false,
      icon: 'healthicons:i-schedule-school-date-time-outline',
      colProps: { span: 7, offset: 1 },
      componentProps: {
        picker: 'month',
        placeholder: ['开始日期', '结束日期'],
        style: { width: '100%' },
        valueFormat: 'YYYY-MM',
        format: 'YYYY-MM',
      },
    },
    {
      field: 'imageProgress',
      label: `${year}` + '年底预计形象进度',
      required: planType === '计划投资项目' ? true : false,
      show: planType === '计划投资项目' ? true : false,
      component: 'Select',
      componentProps: {
        options: [
          { label: '未施工', value: '未施工' },
          { label: '施工前期', value: '施工前期' },
          { label: '施工中期', value: '施工中期' },
          { label: '施工后期', value: '施工后期' },
          { label: '完工', value: '完工' },
          { label: '竣工', value: '竣工' },
        ],
      },
      labelWidth: 400,
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'competentDepartment',
      label: '项目主管部门',
      required: true,
      component: 'Input',
      colProps: { span: 7, offset: 1 },
    },
    // {
    //   field: 'fundingGap',
    //   label: '2024资金缺口:',
    //   labelWidth: 200,
    //   required: true,
    //   component: 'InputNumber',
    //   componentProps: {
    //     addonAfter: '万元',
    //   },
    //   colProps: { span: 7, offset: 1 },
    // },
    {
      label: '备注(资金缺口解决途径)',
      field: 'remarks',
      labelWidth: 300,
      component: 'InputTextArea',
      componentProps: {
        maxlength: 100,
        showCount: true,
      },
      colProps: { span: 7, offset: 1 },
    },
  ];
}
