import { BasicColumn, FormSchema } from '@/components/Table';
import { useUserStore } from '@/store/modules/user';

const deptId = '' + useUserStore().userInfo.deptParentId;
//主模块-已竣工列表页
export const columns: (
  | { dataIndex: string; width: number; title: string }
  | { dataIndex: string; width: number; title: string }
  | { dataIndex: string; width: number; title: string }
  | { dataIndex: string; width: number; title: string }
  | { dataIndex: string; width: number; title: string }
  | { dataIndex: string; width: number; title: string }
  | { dataIndex: string; width: number; title: string }
)[] = [
  {
    title: '序号',
    dataIndex: 'serialNumber', // 这个dataIndex仅作为标识，不对应实际数据字段
    width: 50, // 可以自定义宽度
    scopedSlots: { customRender: 'bodyCell' }, // 对应模板中的具名插槽
  },
  {
    title: '年度',
    dataIndex: 'filingCycle',
    width: 200,
  },
  {
    title: '项目类型',
    dataIndex: 'planType',
    width: 180,
  },
  // {
  //   title: '合同额合计(万元)',
  //   dataIndex: 'contractAmount',
  //   width: 180,
  // },
  // {
  //   title: '年资金计划额合计(万元)',
  //   dataIndex: 'annualFund',
  //   width: 180,
  // },
  // {
  //   title: '竣工结算额合计(万元)',
  //   dataIndex: 'completionSettlement',
  //   width: 180,
  // },
  // {
  //   title: '年资金缺口合计(万元)',
  //   dataIndex: 'fundingGap',
  //   width: 180,
  // },
  {
    title: '公司名称',
    dataIndex: 'company',
    width: 180,
  },
  {
    title: '最新更新人',
    dataIndex: 'updateBy',
    width: 180,
  },
  {
    title: '最新更新时间',
    dataIndex: 'updateTime',
    width: 180,
  },
  {
    title: '审核状态',
    dataIndex: 'auditResult',
    ifShow: deptId != '100',
    width: 180,
  },
  {
    title: '审核人',
    dataIndex: 'auditingBy',
    width: 180,
  },
  {
    title: '审核时间',
    dataIndex: 'auditingTime',
    width: 180,
  },
];
export const searchSchema: FormSchema[] = [
  {
    field: 'filingCycle',
    label: '',
    defaultValue: new Date(),
    component: 'DatePicker',
    componentProps: {
      placeholder: '选择填报周期',
      picker: 'year',
      valueFormat: 'YYYY',
      format: 'YYYY',
      style: { width: '100%' },
      allowClear: false,
    },
    colProps: { span: 4 },
  },
  {
    field: 'company',
    label: '',
    component: 'Select',
    ifShow: deptId === '100',
    componentProps: {
      options: [],
      placeholder: '公司名称',
    },
    colProps: { span: 4 },
  },
  {
    ifShow: false,
    field: 'planType',
    label: '',
    defaultValue: '计划投资项目',
    component: 'Select',
    componentProps: {
      options: [
        { label: '计划投资项目', value: '计划投资项目' },
        { label: '已竣工验收项目', value: '已竣工验收项目' },
      ],
      placeholder: '项目类型',
    },
    colProps: { span: 4 },
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'filingCycle',
    label: '',
    defaultValue: '',
    component: 'DatePicker',
    componentProps: {
      placeholder: '选择填报周期',
      picker: 'year',
      valueFormat: 'YYYY',
      format: 'YYYY',
      style: { width: '100%' },
    },
    colProps: { span: 4 },
  },
  {
    field: 'company',
    label: '',
    component: 'Select',
    ifShow: deptId == '100',
    componentProps: {
      options: [
        { label: '公司A', value: '0' },
        { label: '公司B', value: '1' },
        { label: '公司C', value: '2' },
      ],
      placeholder: '公司名称',
    },
    colProps: { span: 4 },
  },
  {
    field: 'planType',
    label: '',
    component: 'Select',
    defaultValue: '计划投资项目',
    ifShow: false,
    componentProps: {
      options: [
        { label: '计划投资项目', value: '计划投资项目' },
        { label: '已竣工验收项目', value: '已竣工验收项目' },
      ],
      placeholder: '项目类型',
    },
    colProps: { span: 4 },
  },
];

export const formSchema: FormSchema[] = [
  // {
  //   field: 'projectName',
  //   label: '项目名称',
  //   required: true,
  //   component: 'Input',
  // },
  // {
  //   field: 'isReserveProject',
  //   label: '是否为储备项目',
  //   component: 'RadioButtonGroup',
  //   defaultValue: '0',
  //   componentProps: {
  //     options: [
  //       { label: '是', value: '1' },
  //       { label: '否', value: '0' },
  //     ],
  //   },
  // },
  // {
  //   field: 'status',
  //   label: '状态',
  //   component: 'RadioButtonGroup',
  //   defaultValue: '0',
  //   componentProps: {
  //     options: [
  //       { label: '启用', value: '1' },
  //       { label: '停用', value: '0' },
  //     ],
  //   },
  // },
  // {
  //   label: '建设模式',
  //   field: 'constructionMode',
  //   component: 'InputTextArea',
  // },
  // {
  //   label: '项目类型',
  //   field: 'projectType',
  //   required: true,
  //   component: 'Input',
  // },
  // {
  //   label: '项目概况',
  //   field: 'projectOverview',
  //   required: true,
  //   component: 'InputTextArea',
  // },
  // {
  //   label: '建设目的及项目功能',
  //   field: 'constructionPurpose',
  //   required: true,
  //   component: 'InputTextArea',
  // },
];
export function getDtailsBasicColumns(year: string, planType: string): BasicColumn[] {
  if (planType === '已竣工验收项目') {
    return [
      {
        title: '序号',
        dataIndex: 'index',
        fixed: 'left',
        width: 180,
        slots: { customRender: 'index' },
      },
      {
        title: '项目名称',
        dataIndex: 'projectName',
        fixed: 'left',
        width: 180,
      },
      {
        title: '建设地点',
        dataIndex: 'constructionSite',
        width: 180,
      },
      {
        title: '立项总投资',
        dataIndex: 'projectInvestment',
        width: 200,
      },
      {
        title: '合同额',
        dataIndex: 'contractAmount',
        width: 150,
      },
      {
        title: '竣工结算额',
        dataIndex: 'completionSettlement',
        width: 150,
      },
      {
        title: parseInt(year) - 1 + '年资金执行情况',
        children: [
          {
            title: '计划额',
            dataIndex: 'annualFund',
            width: 150,
          },
          {
            title: '实付额',
            dataIndex: 'actualPay',
            width: 150,
          },
        ],
      },
      {
        title: parseInt(year) - 1 + '年底前累计实付额',
        dataIndex: 'totalActualPay',
        width: 150,
      },
      {
        title: year + '年资金计划额',
        children: [
          {
            title: '合计',
            dataIndex: 'totalValue',
            width: 150,
          },
          {
            title: '一季度',
            dataIndex: 'totalValueOne',
            width: 150,
          },
          {
            title: '二季度',
            dataIndex: 'totalValueTwo',
            width: 150,
          },
          {
            title: '三季度',
            dataIndex: 'totalValueThree',
            width: 150,
          },
          {
            title: '四季度',
            dataIndex: 'totalValueFour',
            width: 150,
          },
        ],
      },
      {
        title: year + '资金来源',
        children: [
          {
            title: '政府拨款',
            children: [
              {
                title: '小计',
                dataIndex: 'governmentGrantTotal',
                width: 150,
              },
              {
                title: '一季度',
                dataIndex: 'governmentGrantOne',
                width: 150,
              },
              {
                title: '二季度',
                dataIndex: 'governmentGrantTwo',
                width: 150,
              },
              {
                title: '三季度',
                dataIndex: 'governmentGrantThree',
                width: 150,
              },
              {
                title: '四季度',
                dataIndex: 'governmentGrantFour',
                width: 150,
              },
            ],
          },
          {
            title: '专项债拨款',
            children: [
              {
                title: '小计',
                dataIndex: 'totalSpecialBond',
                width: 150,
              },
              {
                title: '一季度',
                dataIndex: 'totalSpecialBondOne',
                width: 150,
              },
              {
                title: '二季度',
                dataIndex: 'totalSpecialBondTwo',
                width: 150,
              },
              {
                title: '三季度',
                dataIndex: 'totalSpecialBondThree',
                width: 150,
              },
              {
                title: '四季度',
                dataIndex: 'totalSpecialBondFour',
                width: 150,
              },
            ],
          },
          {
            title: '银行融资',
            children: [
              {
                title: '小计',
                dataIndex: 'totalBankFinancing',
                width: 150,
              },
              {
                title: '一季度',
                dataIndex: 'totalBankFinancingOne',
                width: 150,
              },
              {
                title: '二季度',
                dataIndex: 'totalBankFinancingTwo',
                width: 150,
              },
              {
                title: '三季度',
                dataIndex: 'totalBankFinancingThree',
                width: 150,
              },
              {
                title: '四季度',
                dataIndex: 'totalBankFinancingFour',
                width: 150,
              },
            ],
          },
          {
            title: '自有资金',
            children: [
              {
                title: '小计',
                dataIndex: 'totalOwnFunds',
                width: 150,
              },
              {
                title: '一季度',
                dataIndex: 'totalOwnFundsOne',
                width: 150,
              },
              {
                title: '二季度',
                dataIndex: 'totalOwnFundsTwo',
                width: 150,
              },
              {
                title: '三季度',
                dataIndex: 'totalOwnFundsThree',
                width: 150,
              },
              {
                title: '四季度',
                dataIndex: 'totalOwnFundsFour',
                width: 150,
              },
            ],
          },
        ],
      },
      {
        title: year + '年资金缺口',
        dataIndex: 'fundingGap',
        width: 150,
      },
      {
        title: '项目主管',
        dataIndex: 'company',
        width: 150,
      },
      {
        title: '备注',
        dataIndex: 'remarks',
        width: 150,
      },
    ];
  } else {
    return [
      {
        title: '序号',
        dataIndex: 'index',
        fixed: 'left',
        width: 180,
        slots: { customRender: 'index' },
      },
      {
        title: '项目名称',
        dataIndex: 'projectName',
        fixed: 'left',
        width: 180,
      },
      {
        title: '建设地点',
        dataIndex: 'constructionSite',
        width: 180,
      },
      {
        title: '立项总投资',
        dataIndex: 'projectInvestment',
        width: 200,
      },
      {
        title: year + '年计划投资',
        dataIndex: 'plannedInvestment',
        width: 150,
      },
      {
        title: parseInt(year) - 1 + '年资金执行情况',
        children: [
          {
            title: '计划额',
            dataIndex: 'annualFund',
            width: 150,
          },
          {
            title: '实付额',
            dataIndex: 'actualPay',
            width: 150,
          },
        ],
      },
      {
        title: parseInt(year) - 1 + '年底前累计实付额',
        dataIndex: 'totalActualPay',
        width: 150,
      },
      {
        title: year + '年资金计划额',
        children: [
          {
            title: '合计',
            dataIndex: 'totalValue',
            width: 150,
          },
          {
            title: '一季度',
            dataIndex: 'totalValueOne',
            width: 150,
          },
          {
            title: '二季度',
            dataIndex: 'totalValueTwo',
            width: 150,
          },
          {
            title: '三季度',
            dataIndex: 'totalValueThree',
            width: 150,
          },
          {
            title: '四季度',
            dataIndex: 'totalValueFour',
            width: 150,
          },
        ],
      },
      {
        title: year + '资金来源',
        children: [
          {
            title: '政府拨款',
            children: [
              {
                title: '小计',
                dataIndex: 'governmentGrantTotal',
                width: 150,
              },
              {
                title: '一季度',
                dataIndex: 'governmentGrantOne',
                width: 150,
              },
              {
                title: '二季度',
                dataIndex: 'governmentGrantTwo',
                width: 150,
              },
              {
                title: '三季度',
                dataIndex: 'governmentGrantThree',
                width: 150,
              },
              {
                title: '四季度',
                dataIndex: 'governmentGrantFour',
                width: 150,
              },
            ],
          },
          {
            title: '专项债拨款',
            children: [
              {
                title: '小计',
                dataIndex: 'totalSpecialBond',
                width: 150,
              },
              {
                title: '一季度',
                dataIndex: 'totalSpecialBondOne',
                width: 150,
              },
              {
                title: '二季度',
                dataIndex: 'totalSpecialBondTwo',
                width: 150,
              },
              {
                title: '三季度',
                dataIndex: 'totalSpecialBondThree',
                width: 150,
              },
              {
                title: '四季度',
                dataIndex: 'totalSpecialBondFour',
                width: 150,
              },
            ],
          },
          {
            title: '银行融资',
            children: [
              {
                title: '小计',
                dataIndex: 'totalBankFinancing',
                width: 150,
              },
              {
                title: '一季度',
                dataIndex: 'totalBankFinancingOne',
                width: 150,
              },
              {
                title: '二季度',
                dataIndex: 'totalBankFinancingTwo',
                width: 150,
              },
              {
                title: '三季度',
                dataIndex: 'totalBankFinancingThree',
                width: 150,
              },
              {
                title: '四季度',
                dataIndex: 'totalBankFinancingFour',
                width: 150,
              },
            ],
          },
          {
            title: '自有资金',
            children: [
              {
                title: '小计',
                dataIndex: 'totalOwnFunds',
                width: 150,
              },
              {
                title: '一季度',
                dataIndex: 'totalOwnFundsOne',
                width: 150,
              },
              {
                title: '二季度',
                dataIndex: 'totalOwnFundsTwo',
                width: 150,
              },
              {
                title: '三季度',
                dataIndex: 'totalOwnFundsThree',
                width: 150,
              },
              {
                title: '四季度',
                dataIndex: 'totalOwnFundsFour',
                width: 150,
              },
            ],
          },
        ],
      },
      {
        title: year + '年资金缺口',
        dataIndex: 'fundingGap',
        width: 150,
      },
      {
        title: '建设性质',
        dataIndex: 'constructionNature',
        width: 150,
      },
      {
        title: '开工时间',
        dataIndex: 'startTime',
        width: 150,
      },
      {
        title: '竣工时间',
        dataIndex: 'endTime',
        width: 150,
      },
      {
        title: year + '年底预计形象进度',
        dataIndex: 'imageProgress',
        width: 150,
      },
      {
        title: '项目主管部门',
        dataIndex: 'competentDepartment',
        width: 150,
      },
      {
        title: '备注',
        dataIndex: 'remarks',
        width: 150,
      },
    ];
  }
}
