import { BasicColumn, FormSchema } from '@/components/Table';
import { useUserStore } from '@/store/modules/user';

const deptId = '' + useUserStore().userInfo.deptParentId;
type CheckedType = boolean | string | number;
export const columns: (
  | { dataIndex: string; width: number; title: string }
  | { dataIndex: string; width: number; title: string }
  | { dataIndex: string; width: number; title: string }
  | { dataIndex: string; width: number; title: string }
  | { dataIndex: string; width: number; title: string }
  | { dataIndex: string; width: number; title: string }
  | { dataIndex: string; width: number; title: string }
)[] = [
  {
    title: '序号',
    dataIndex: 'serialNumber', // 这个dataIndex仅作为标识，不对应实际数据字段
    width: 50, // 可以自定义宽度
    scopedSlots: { customRender: 'bodyCell' }, // 对应模板中的具名插槽
  },
  {
    title: '填报周期',
    dataIndex: 'filingCycle',
    width: 200,
  },
  {
    title: '类型',
    dataIndex: 'planType',
    width: 180,
  },
  {
    title: '项目数量',
    dataIndex: 'totalProject',
    width: 180,
  },
  // {
  //   title: '总投资',
  //   dataIndex: 'totalInvestment',
  //   width: 180,
  // },
  // {
  //   title: '合同总额合计',
  //   dataIndex: 'totalContract',
  //   width: 180,
  // },
  {
    title: '三年滚动投资计划合计',
    dataIndex: 'totalRollingInvestment',
    width: 180,
  },
  {
    title: '公司名称',
    dataIndex: 'company',
    width: 180,
  },
  {
    title: '最新更新人',
    dataIndex: 'updateBy',
    width: 180,
  },
  {
    title: '最新更新时间',
    dataIndex: 'updateTime',
    width: 180,
  },
  {
    title: '审核状态',
    dataIndex: 'planResult',
    ifShow: deptId != '100',
    width: 180,
  },
  {
    title: '审核人',
    dataIndex: 'auditingBy',
    width: 180,
  },
  {
    title: '审核时间',
    dataIndex: 'auditingTime',
    width: 180,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'filingCycle',
    label: '',
    component: 'DatePicker',
    componentProps: {
      placeholder: '选择填报周期',
      style: { width: '100%' },
      picker: 'year',
      valueFormat: 'YYYY',
      format: 'YYYY',
    },
    colProps: { span: 4 },
  },
  {
    ifShow: false,
    field: 'planType',
    label: '',
    defaultValue: '自投',
    component: 'Select',
    componentProps: {
      options: [
        { label: '自投', value: '自投' },
        { label: '代建', value: '代建' },
        { label: '承建', value: '承建' },
        { label: '储备', value: '储备' },
      ],
      placeholder: '类型',
    },
    colProps: { span: 4 },
  },
  {
    field: 'company',
    label: '',
    component: 'Select',
    ifShow: deptId == '100',
    componentProps: {
      options: [
        { label: '公司A', value: '0' },
        { label: '公司B', value: '1' },
        { label: '公司C', value: '2' },
      ],
      placeholder: '公司名称',
    },
    colProps: { span: 4 },
  },
];
