import { BasicColumn, FormSchema } from '@/components/Table';
import { useUserStore } from '@/store/modules/user';

const deptId = useUserStore().userInfo.deptParentId;
//主模块-月度投资列表页
export const columns: BasicColumn[] = [
  {
    title: '序号',
    dataIndex: 'serialNumber', // 这个dataIndex仅作为标识，不对应实际数据字段
    width: 50, // 可以自定义宽度
    scopedSlots: { customRender: 'bodyCell' }, // 对应模板中的具名插槽
  },
  {
    title: '月份',
    dataIndex: 'monthYear',
    width: 200,
  },
  // {
  //   title: '类型',
  //   dataIndex: 'implementingEntity',
  //   width: 180,
  // },
  {
    title: '合同额总计(万元)',
    dataIndex: 'totalcontractamount',
    width: 180,
  },
  {
    title: '资金缺口总计(万元)',
    dataIndex: 'totalfundgap',
    width: 180,
  },
  // {
  //   title: '年资金缺口(万元)',
  //   dataIndex: 'totalfundgapyear',
  //   width: 180,
  // },
  {
    title: '公司名称',
    dataIndex: 'companyName',
    width: 180,
  },
  {
    title: '最新更新人',
    dataIndex: 'updateBy',
    width: 180,
  },
  {
    title: '最新更新时间',
    dataIndex: 'updateTime',
    width: 180,
  },
  {
    title: '审核状态',
    dataIndex: 'examineStatus',
    width: 180,
    ifShow: deptId != '100',
  },
  {
    title: '审核人',
    dataIndex: 'revieweUser',
    width: 180,
    ifShow: deptId != '100',
  },
  {
    title: '审核时间',
    dataIndex: 'reviewTime',
    width: 180,
    ifShow: deptId != '100',
  },
];
export const lastPlanColumns: BasicColumn[] = [
  {
    title: '项目名称',
    dataIndex: 'projectName',
    width: 180,
  },
  {
    title: '合同名称',
    dataIndex: 'contrcatName',
    width: 180,
  },
  {
    title: '填报周期',
    dataIndex: 'monthYear',
    width: 180,
  },
  {
    title: '累计支付数',
    dataIndex: 'accumulatePayment',
    width: 180,
  },
  {
    title: '上月实付数',
    dataIndex: 'lastMonthActual',
    width: 180,
  },
  {
    title: '上月计划数',
    dataIndex: 'lastMonthPlan',
    width: 180,
  },
  {
    title: '上月实际完成值',
    dataIndex: 'completionValueActual',
    width: 180,
  },
  {
    title: '本月计划完成值',
    dataIndex: 'planCompletionValue',
    width: 180,
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'monthYear',
    label: '',
    component: 'DatePicker',
    componentProps: {
      placeholder: '选择填报周期',
      picker: 'month',
      valueFormat: 'YYYY-MM',
      format: 'YYYY-MM',
      style: { width: '100%' },
    },
    colProps: { span: 4 },
  },
  // {
  //   field: 'type',
  //   label: '',
  //   component: 'Select',
  //   componentProps: {
  //     options: [
  //       { label: '工程', value: '1' },
  //       { label: '承建', value: '0' },
  //       { label: '储备', value: '2' },
  //     ],
  //     placeholder: '类型',
  //   },
  //   colProps: { span: 4 },
  // },
  {
    field: 'companyName',
    label: '',
    component: 'Select',
    ifShow: deptId == '100',
    componentProps: {
      options: [
        { label: '公司A', value: '0' },
        { label: '公司B', value: '1' },
        { label: '公司C', value: '2' },
      ],
      placeholder: '公司名称',
    },
    colProps: { span: 4 },
  },
];

export const formSchema: FormSchema[] = [
  // {
  //   field: 'projectName',
  //   label: '项目名称',
  //   required: true,
  //   component: 'Input',
  // },
  // {
  //   field: 'isReserveProject',
  //   label: '是否为储备项目',
  //   component: 'RadioButtonGroup',
  //   defaultValue: '0',
  //   componentProps: {
  //     options: [
  //       { label: '是', value: '1' },
  //       { label: '否', value: '0' },
  //     ],
  //   },
  // },
  // {
  //   field: 'status',
  //   label: '状态',
  //   component: 'RadioButtonGroup',
  //   defaultValue: '0',
  //   componentProps: {
  //     options: [
  //       { label: '启用', value: '1' },
  //       { label: '停用', value: '0' },
  //     ],
  //   },
  // },
  // {
  //   label: '建设模式',
  //   field: 'constructionMode',
  //   component: 'InputTextArea',
  // },
  // {
  //   label: '项目类型',
  //   field: 'projectType',
  //   required: true,
  //   component: 'Input',
  // },
  // {
  //   label: '项目概况',
  //   field: 'projectOverview',
  //   required: true,
  //   component: 'InputTextArea',
  // },
  // {
  //   label: '建设目的及项目功能',
  //   field: 'constructionPurpose',
  //   required: true,
  //   component: 'InputTextArea',
  // },
];

export const seach: FormSchema[] = [
  {
    field: 'monthYear',
    label: '填报周期',
    component: 'DatePicker',
    defaultValue: new Date(),
    componentProps: {
      allowClear: false,
      placeholder: '选择填报周期',
      picker: 'month',
      valueFormat: 'YYYY-MM',
      format: 'YYYY-MM',
      style: { width: '100%' },
      // onChange: (e) => {
      //   params.value.monthYear = e;
      // },
    },
    colProps: { span: 4 },
  },
  {
    field: 'deptId',
    label: '所属公司',
    component: 'Select',
    ifShow: deptId == '100',
    componentProps: {
      options: [],
      placeholder: '请选择所属公司',
    },
    colProps: { span: 4 },
  },
];
