import { FormSchema, BasicColumn } from '@/components/Table';

export function getBasicColumns(): BasicColumn[] {
  return [
    {
      title: '年份',
      dataIndex: 'year',
      width: 80,
    },
    {
      title: '金额(万元)',
      dataIndex: 'amount',
      width: 150,
      // sorter: true,
      // defaultHidden: true,
      edit: true,
    },
  ];
}
/*月度计划主模块-创建月度资金计划-page页的前半部分*/
export const formSchema: FormSchema[] = [
  {
    field: 'projectName',
    label: '项目名称',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'sourceType',
    label: '资金来源类型',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
];
/*月度计划主模块-创建月度资金计划-page页的后半部分*/
export const subFormSchema: FormSchema[] = [
  {
    field: 'contrcatName',
    label: '合同名称',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'collectingUnit',
    label: '收款单位',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'contractAmount',
    label: '合同金额',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'investmentAmount',
    label: '结算金额',
    // required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'paymentLevel',
    label: '支付等级',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        { label: 'A（必须支付）', value: 'A（必须支付）' },
        { label: 'B（可暂缓支付但有维稳风险）', value: 'B（可暂缓支付但有维稳风险）' },
        { label: 'C（随财政拨款支付，无维稳风险）', value: 'C（随财政拨款支付，无维稳风险）' },
      ],
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'field11',
    component: 'BasicTitle',
    label: '产值完成情况',
    componentProps: {
      // line: true,
      span: true,
    },
    colProps: {
      span: 24,
    },
  },
  {
    field: 'completionValueActual',
    label: '上月实际完成值',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
    colProps: { span: 5, offset: 1 },
  },
  {
    field: 'accumulateCompletionValue',
    label: '累计完成值',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
    colProps: { span: 5, offset: 1 },
  },
  {
    field: 'planCompletionValue',
    label: '本月计划完成值',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
    colProps: { span: 5, offset: 1 },
  },
  {
    field: 'field11',
    component: 'BasicTitle',
    label: '资金支付情况',
    componentProps: {
      // line: true,
      span: true,
    },
    colProps: {
      span: 24,
    },
  },
  {
    field: 'lastMonthPlan',
    label: '上月计划数',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
    colProps: { span: 5, offset: 1 },
  },
  {
    field: 'lastMonthActual',
    label: '上月实付数',
    required: true,
    component: 'InputNumber',
    componentProps: ({ formModel }) => ({
      addonAfter: '万元',
      onChange: (value) => {
        formModel.accumulatePayment = numberAdd(formModel.accumulatePaymentReserve || 0, value);
      },
    }),
    colProps: { span: 5, offset: 1 },
  },
  {
    field: 'accumulatePaymentReserve',
    label: '累计支付数预留',
    required: false,
    ifShow: false,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
      disabled: true,
    },
    colProps: { span: 5, offset: 1 },
  },
  {
    field: 'accumulatePayment',
    label: '累计支付数',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
      disabled: true,
    },
    colProps: { span: 5, offset: 1 },
  },
  {
    field: 'thisPlanNumber',
    label: '本月计划数(资金来源累加值)',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
      disabled: true,
    },
    colProps: { span: 5, offset: 1 },
  },
  {
    field: 'field11',
    component: 'BasicTitle',
    label: '资金来源',
    componentProps: {
      // line: true,
      span: true,
    },
    colProps: {
      span: 24,
    },
  },
  {
    field: 'specialFund',
    label: '专项债拨款',
    required: true,
    component: 'InputNumber',
    componentProps: ({ formModel }) => {
      return {
        addonAfter: '万元',
        onChange(e) {
          formModel.thisPlanNumber =
            e +
            (formModel.governmentFund || 0) +
            (formModel.banFinancing || 0) +
            (formModel.ownFund || 0) +
            (formModel.fundGap || 0);
        },
      };
    },

    colProps: { span: 5, offset: 1 },
  },
  {
    field: 'governmentFund',
    label: '政府拨款',
    required: true,
    component: 'InputNumber',
    componentProps: ({ formModel }) => {
      return {
        addonAfter: '万元',
        onChange(e) {
          formModel.thisPlanNumber =
            e +
            (formModel.specialFund || 0) +
            (formModel.banFinancing || 0) +
            (formModel.ownFund || 0) +
            (formModel.fundGap || 0);
        },
      };
    },
    colProps: { span: 5, offset: 1 },
  },
  {
    field: 'banFinancing',
    label: '银行融资',
    required: true,
    component: 'InputNumber',
    componentProps: ({ formModel }) => {
      return {
        addonAfter: '万元',
        onChange(e) {
          formModel.thisPlanNumber =
            e +
            (formModel.specialFund || 0) +
            (formModel.governmentFund || 0) +
            (formModel.ownFund || 0) +
            (formModel.fundGap || 0);
        },
      };
    },
    colProps: { span: 5, offset: 1 },
  },
  {
    field: 'ownFund',
    label: '自有资金',
    required: true,
    component: 'InputNumber',
    componentProps: ({ formModel }) => {
      return {
        addonAfter: '万元',
        onChange(e) {
          formModel.thisPlanNumber =
            e +
            (formModel.specialFund || 0) +
            (formModel.governmentFund || 0) +
            (formModel.banFinancing || 0) +
            (formModel.fundGap || 0);
        },
      };
    },
    colProps: { span: 5, offset: 1 },
  },
  {
    field: 'fundGap',
    label: '资金缺口',
    // required: true,
    component: 'InputNumber',

    componentProps: ({ formModel }) => {
      return {
        addonAfter: '万元',
        onChange(e) {
          formModel.thisPlanNumber =
            e +
            (formModel.specialFund || 0) +
            (formModel.governmentFund || 0) +
            (formModel.banFinancing || 0) +
            (formModel.ownFund || 0);
        },
      };
    },

    colProps: { span: 5, offset: 1 },
  },
  {
    field: 'remark',
    label: '说明（资金缺口解决途径）',
    // required: true,
    component: 'InputTextArea',
    componentProps: {
      maxlength: 100,
      showCount: true,
    },
    dynamicRules: ({ values }) => {
      return values.fundGap ? [{ required: true, message: '说明必填' }] : [];
    },
    colProps: { span: 7, offset: 1 },
  },
];
function numberAdd(arg1, arg2) {
  let r1, r2, m, n;
  try {
    r1 = arg1.toString().split('.')[1].length;
  } catch (e) {
    r1 = 0;
  }
  try {
    r2 = arg2.toString().split('.')[1].length;
  } catch (e) {
    r2 = 0;
  }
  m = Math.pow(10, Math.max(r1, r2));
  n = r1 >= r2 ? r1 : r2;
  return ((arg1 * m + arg2 * m) / m).toFixed(n);
}
