import { BasicColumn, FormSchema } from '@/components/Table';
import { useUserStore } from '@/store/modules/user';

const deptId = '' + useUserStore().userInfo.deptParentId;
/*创建完成情况列表页显示项*/
export const columns: BasicColumn[] = [
  {
    title: '序号',
    dataIndex: 'serialNumber', // 这个dataIndex仅作为标识，不对应实际数据字段
    width: 50, // 可以自定义宽度 // 对应模板中的具名插槽
  },
  {
    title: '填报周期',
    dataIndex: 'filingCycle',
    width: 200,
  },
  {
    title: '类型',
    dataIndex: 'planType',
    width: 180,
  },
  // {
  //   title: '实际完成投资额合计(万元)',
  //   dataIndex: 'actualInvestment',
  //   width: 180,
  // },
  // {
  //   title: '年实际产值合计(万元)',
  //   dataIndex: 'outputValue',
  //   width: 180,
  // },
  // {
  //   title: '年实付资金合计(万元)',
  //   dataIndex: 'payment',
  //   width: 180,
  // },
  {
    title: '项目数量',
    dataIndex: 'totalProject',
    width: 180,
  },
  {
    title: '公司名称',
    dataIndex: 'company',
    width: 180,
  },
  {
    title: '最新更新人',
    dataIndex: 'updateBy',
    width: 180,
  },
  {
    title: '最新更新时间',
    dataIndex: 'updateTime',
    width: 180,
  },
  {
    title: '审核状态',
    dataIndex: 'completionResult',
    ifShow: deptId != '100',
    width: 180,
  },
  {
    title: '审核人',
    dataIndex: 'auditingBy',
    width: 180,
  },
  {
    title: '审核时间',
    dataIndex: 'auditingTime',
    width: 180,
  },
];
/*选择投资计划弹窗列表内容*/
export const searchModelFormSchema: FormSchema[] = [
  {
    field: 'filingCycle',
    label: '',
    ifShow: false,
    component: 'DatePicker',
    componentProps: {
      placeholder: '年度',
      picker: 'year',
      valueFormat: 'YYYY',
      format: 'YYYY',
      style: {
        width: '100%',
      },
    },
    colProps: { span: 4 },
  },
  {
    field: 'planType',
    label: '',
    ifShow: false,
    component: 'Select',
    componentProps: {
      placeholder: '类型',
      options: [
        {
          label: '自投',
          value: '自投',
        },
        {
          label: '代建',
          value: '代建',
        },
        {
          label: '承建',
          value: '承建',
        },
      ],
    },
    colProps: { span: 4 },
  },
];
/*创建完成情况列表页显示项*/
export const modelColumns: BasicColumn[] = [
  {
    title: '序号',
    dataIndex: 'serialNumber', // 这个dataIndex仅作为标识，不对应实际数据字段
    width: 50, // 可以自定义宽度
  },
  {
    title: '填报周期',
    dataIndex: 'filingCycle',
    width: 200,
  },
  {
    title: '类型',
    dataIndex: 'planType',
    width: 180,
  },
  {
    title: '项目数量',
    dataIndex: 'totalProject',
    width: 180,
  },
  // {
  //   title: '总投资',
  //   dataIndex: 'totalInvestment',
  //   width: 180,
  // },
  // {
  //   title: '合同总额合计',
  //   dataIndex: 'totalContract',
  //   width: 180,
  // },
  // {
  //   title: '三年滚动投资计划合计',
  //   dataIndex: 'totalRollingInvestment',
  //   width: 180,
  // },
  {
    title: '公司名称',
    dataIndex: 'company',
    width: 180,
  },
  {
    title: '最新更新人',
    dataIndex: 'updateBy',
    width: 180,
  },
  {
    title: '最新更新时间',
    dataIndex: 'updateTime',
    width: 180,
  },
  {
    title: '审核状态',
    dataIndex: 'planResult',
    width: 180,
  },
  {
    title: '审核人',
    dataIndex: 'auditingBy',
    width: 180,
  },
  {
    title: '审核时间',
    dataIndex: 'auditingTime',
    width: 180,
  },
];
/*创建完成情况列表页筛选项*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'filingCycle',
    label: '',
    component: 'DatePicker',
    componentProps: {
      placeholder: '选择填报周期',
      style: { width: '100%' },
      picker: 'year',
      valueFormat: 'YYYY',
      format: 'YYYY',
    },
    colProps: { span: 4 },
  },
  {
    field: 'planType',
    label: '',
    component: 'Select',
    defaultValue: '自投',
    componentProps: {
      options: [
        { label: '自投', value: '自投' },
        { label: '代建', value: '代建' },
        { label: '承建', value: '承建' },
      ],
      placeholder: '类型',
    },
    ifShow: false,
    colProps: { span: 4 },
  },
  {
    field: 'companyId',
    label: '',
    component: 'Select',
    ifShow: deptId === '100',
    componentProps: {
      options: [
        { label: '公司A', value: '0' },
        { label: '公司B', value: '1' },
        { label: '公司C', value: '2' },
      ],
      placeholder: '公司名称',
    },
    colProps: { span: 4 },
  },
];

/*创建完成情况-承建*/
export const formSchema1: FormSchema[] = [
  {
    field: 'projectName',
    label: '项目名称',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'constructionSite',
    label: '建设地点',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'constructionMode',
    label: '建设模式',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'projectType',
    label: '项目类型',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'constructionScale',
    label: '建设规模',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'projectOverview',
    label: '项目概况',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'fundingSource',
    label: '资金来源',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'implementingEntity',
    label: '实施主体',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'contractAmount',
    label: '合同总额',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'contract',
    label: '合同方式',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'attribute',
    label: '建设性质',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        { label: '新建', value: '0' },
        { label: '结转', value: '1' },
        { label: '缓建', value: '2' },
      ],
      disabled: true,
      style: { border: 'none' },
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'time',
    label: '开竣工时间',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'completionSchedule',
    label: ' 2024年底形象进度',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: 'A(已经立项实施的跨年工程)',
          value: 'A(已经立项实施的跨年工程)',
        },
        {
          label: 'B(该年度必须建设的项目)',
          value: 'B(该年度必须建设的项目)',
        },
        {
          label: 'C(可缓建项目)',
          value: 'C(可缓建项目)',
        },
      ],
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'outputValue',
    label: ' 2024年之前完成总产值(不含2024年)',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'planNum',
    label: '2024年计划产值',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'actualOutputValue',
    label: ' 2024年实际产值',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'planFunds',
    label: ' 2024年计划资金',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      style: { border: 'none' },
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'actualPay',
    label: ' 2024年实付资金',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    label: '备注',
    field: 'completionRemarks',
    // required: true,
    component: 'InputTextArea',
    componentProps: {
      maxlength: 100,
      showCount: true,
    },
    colProps: { span: 7, offset: 1 },
  },
];
/*创建完成情况-非承建*/
export function formSchema(year, planType): FormSchema[] {
  return [
    {
      field: 'projectName',
      label: '项目名称',
      required: true,
      component: 'Input',
      componentProps: {
        readonly: true,
        disabled: true,
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'fundingSource',
      label: '资金来源',
      required: true,
      component: 'Input',
      componentProps: {
        readonly: true,
        disabled: true,
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'constructionScale',
      label: '建设规模',
      required: true,
      component: 'Input',
      componentProps: {
        readonly: true,
        disabled: true,
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'projectOverview',
      label: '项目概况',
      required: true,
      component: 'Input',
      componentProps: {
        readonly: true,
        disabled: true,
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'constructionMode',
      label: '建设模式',
      required: true,
      component: 'Input',
      componentProps: {
        readonly: true,
        disabled: true,
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'attribute',
      label: '建设性质',
      required: true,
      component: 'Select',
      componentProps: {
        options: [
          { label: '新建', value: '新建' },
          { label: '结转', value: '结转' },
          { label: '缓建', value: '缓建' },
        ],
        style: { border: 'none' },
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'totalInvestment',
      label: '立项总投资',
      required: planType != '承建',
      show: planType != '承建',
      component: 'InputNumber',
      componentProps: {
        addonAfter: '万元',
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'projectApproval',
      label: '实际控制总投资',
      required: false,
      show: planType != '承建',
      component: 'InputNumber',
      componentProps: {
        addonAfter: '万元',
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'contractAmount',
      label: '合同总额',
      show: planType === '承建',
      required: planType === '承建',
      component: 'InputNumber',
      componentProps: {
        addonAfter: '万元',
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'completionSchedule',
      label: year + '年底形象进度',
      required: true,
      component: 'Select',
      componentProps: {
        options: [
          { label: '未施工', value: '未施工' },
          { label: '施工前期', value: '施工前期' },
          { label: '施工中期', value: '施工中期' },
          { label: '施工后期', value: '施工后期' },
          { label: '完工', value: '完工' },
          { label: '竣工', value: '竣工' },
        ],
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'planCompleteOutputValue',
      label: year + '年计划完成产值',
      required: planType === '承建',
      show: planType === '承建',
      component: 'InputNumber',
      componentProps: {
        addonAfter: '万元',
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'planOutputValue',
      label: year + '年计划投资额',
      required: planType != '承建',
      show: planType != '承建',
      component: 'InputNumber',
      componentProps: {
        addonAfter: '万元',
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'actualOutputValue',
      label: planType === '承建' ? year + '年实际完成产值' : year + '年实际投资额',
      required: true,
      show: true,
      component: 'InputNumber',
      componentProps: {
        addonAfter: '万元',
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'outputValue',
      label:
        planType === '承建'
          ? year + '年之前完成总产值(不含' + year + '年)'
          : year + '年之前完成总投资额(不含' + year + '年)',
      required: true,
      show: true,
      component: 'InputNumber',
      componentProps: {
        addonAfter: '万元',
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'planFunds',
      label: year + '年计划资金',
      required: true,
      component: 'InputNumber',
      componentProps: {
        addonAfter: '万元',
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'actualPay',
      label: year + '年实付资金',
      required: true,
      component: 'InputNumber',
      componentProps: {
        addonAfter: '万元',
      },
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'competentDepartment',
      label: '项目主管部门',
      component: 'Input',
      colProps: { span: 7, offset: 1 },
    },
    {
      field: 'time',
      component: 'RangePicker',
      label: '开竣工时间',
      required: true,
      icon: 'healthicons:i-schedule-school-date-time-outline',
      colProps: { span: 7, offset: 1 },
      componentProps: {
        picker: 'month',
        placeholder: ['开始日期', '结束日期'],
        style: { width: '100%' },
        valueFormat: 'YYYY-MM',
        format: 'YYYY-MM',
      },
    },
    {
      field: 'contract',
      label: '合同方式',
      required: true,
      component: 'Select',
      componentProps: {
        options: [
          { label: '总包', value: '总包' },
          { label: '分包', value: '分包' },
        ],
      },
      show: planType === '承建',
      colProps: { span: 7, offset: 1 },
    },
    {
      label: '备注(未完成投资计划项目请备注原因)',
      labelWidth: 300,
      field: 'completionRemarks',
      component: 'InputTextArea',
      componentProps: {
        maxlength: 100,
        showCount: true,
      },
      colProps: { span: 7, offset: 1 },
    },
  ];
}

/*从投资中选择项目的弹窗内容*/
export const modelColumns2: BasicColumn[] = [
  {
    title: '序号',
    dataIndex: 'serialNumber', // 这个dataIndex仅作为标识，不对应实际数据字段
    width: 50, // 可以自定义宽度
  },
  {
    dataIndex: 'filingCycle',
    title: '填报年度',
    width: 180,
  },
  {
    title: '项目名称',
    dataIndex: 'projectName',
    width: 200,
  },
  {
    dataIndex: 'constructionSite',
    title: '立项主体',
    width: 180,
  },
  {
    dataIndex: 'fundingSource',
    title: '资金来源',
    width: 180,
  },
  {
    dataIndex: 'constructionScale',
    title: '建设规模',
    width: 180,
  },
  {
    dataIndex: 'projectOverview',
    title: '项目概况',
    width: 180,
  },
  {
    dataIndex: 'constructionMode',
    title: '建设模式',
    width: 180,
  },
  {
    dataIndex: 'implementingEntity',
    title: '实施主体',
    width: 180,
  },
  {
    dataIndex: 'totalInvestment',
    title: '总投资',
    width: 180,
  },
  {
    dataIndex: 'competentDepartment',
    title: '项目主管部门',
    width: 180,
  },
  {
    dataIndex: 'attribute',
    title: '建设性质',
    width: 180,
  },
  {
    dataIndex: 'time',
    title: '开竣工时间',
    width: 180,
  },
];
