import { FormSchema } from '@/components/Form';
import { useUserStore } from '@/store/modules/user';
import { BasicColumn } from '@/components/Table';
import moment from 'moment';

const deptId = useUserStore().userInfo.deptParentId;
export const searchForm: FormSchema[] = [
  {
    field: 'filingCycle',
    label: '',
    defaultValue: new Date(),
    component: 'DatePicker',
    componentProps: {
      placeholder: '选择填报周期',
      style: { width: '100%' },
      picker: 'year',
      defaultValue: moment().format('YYYY'),
      valueFormat: 'YYYY',
      format: 'YYYY',
    },
    colProps: { span: 4 },
  },
  {
    field: 'planType',
    label: '',
    defaultValue: '自投',
    component: 'Select',
    componentProps: {
      defaultValue: '自投',
      options: [
        { label: '自投', value: '自投' },
        { label: '代建', value: '代建' },
        { label: '承建', value: '承建' },
        { label: '储备', value: '储备' },
      ],
      placeholder: '类型',
    },
    colProps: { span: 4 },
  },
  {
    field: 'company',
    label: '',
    show: deptId == '100',
    component: 'Select',
    componentProps: {
      options: [],
      placeholder: '公司名称',
    },
    colProps: { span: 4 },
  },
];
export function getBasicColumns(year: string, planType: string): BasicColumn[] {
  return [
    {
      title:
        year == ''
          ? planType + '工程项目投资计划完成情况'
          : year + '年' + planType + '工程项目投资计划完成情况',
      colSpan: 8,
      children: [
        {
          title: '公司名称',
          dataIndex: 'company',
          fixed: 'left',
          width: 250,
          customCell: (_, any) => ({
            rowSpan: _.companyrowSpan,
          }),
        },
        {
          title: '项目类型',
          dataIndex: 'projectType',
          fixed: 'left',
          width: 250,
          slots: { customRender: 'projectType' },
        },
        {
          title: '项目个数',
          dataIndex: 'proNum',
          width: 150,
        },
        {
          title: '总合同额(万元)',
          dataIndex: 'contractAmount',
          className: planType === '承建' ? 'tableShow' : 'tableHiddle',
        },
        {
          title: year + '年计划完成产值',
          dataIndex: 'planCompleteOutputValue',
          className: planType === '承建' ? 'tableShow' : 'tableHiddle',
        },
        {
          title: year + '年实际完成产值',
          dataIndex: 'actualOutputValue',
          className: planType === '承建' ? 'tableShow' : 'tableHiddle',
        },
        {
          title: '总投资额(万元)',
          dataIndex: 'totalInvestment',
          className: planType !== '承建' ? 'tableShow' : 'tableHiddle',
        },
        {
          title: year + '年计划投资额',
          dataIndex: 'planOutputValue',
          className: planType !== '承建' ? 'tableShow' : 'tableHiddle',
        },
        {
          title: year + '年实际完成投资额',
          dataIndex: 'actualOutputValue',
          className: planType != '承建' ? 'tableShow' : 'tableHiddle',
        },
        {
          title: year + '年计划资金',
          dataIndex: 'planFunds',
          className: planType != '储备' ? 'tableShow' : 'tableHiddle',
        },
        {
          title: year + '年实付资金',
          dataIndex: 'actualPay',
          className: planType != '储备' ? 'tableShow' : 'tableHiddle',
        },
      ],
    },
  ];
}
export function getDtailsBasicColumns(year: string, planType: string): BasicColumn[] {
  const column: BasicColumn[] = [
    {
      title: '序号',
      dataIndex: 'index',
      fixed: 'left',
      width: 180,
      slots: { customRender: 'index' },
      ifShow: true,
    },
    {
      title: '项目名称',
      dataIndex: 'projectName',
      fixed: 'left',
      width: 180,
      ifShow: true,
    },
    {
      title: '建设地点',
      dataIndex: 'constructionSite',
      width: 180,
      ifShow: true,
    },
    {
      title: '项目概况',
      dataIndex: 'projectOverview',
      width: 200,
      ifShow: true,
    },
    {
      title: '建设规模',
      dataIndex: 'constructionScale',
      width: 150,
      ifShow: true,
    },
    {
      title: '建设目的及项目功能',
      dataIndex: 'constructionPurpose',
      width: 150,
      ifShow: true,
    },
    {
      title: '建设模式',
      dataIndex: 'constructionMode',
      width: 150,
      ifShow: true,
    },
    {
      title: '资金来源',
      dataIndex: 'fundingSource',
      width: 150,
      ifShow: true,
    },
    {
      title: '项目类型',
      dataIndex: 'projectType',
      width: 150,
      ifShow: true,
    },
    {
      title: '总投资',
      dataIndex: 'totalInvestment',
      ifShow: planType !== '承建',
      width: 150,
    },
    {
      title: year + '年之前总投资额(不包含' + year + '年)',
      dataIndex: 'outputValue',
      ifShow: planType !== '承建',
      width: 150,
    },
    {
      title: year + '年计划投资额',
      dataIndex: 'planOutputValue',
      ifShow: planType !== '承建',
      width: 150,
    },
    {
      title: year + '年实际完成投资额',
      dataIndex: 'actualOutputValue',
      ifShow: planType !== '承建',
      width: 150,
    },
    {
      title: year + '年计划资金',
      dataIndex: 'planFunds',
      ifShow: planType !== '承建',
      width: 150,
    },
    {
      title: year + '年实付资金',
      dataIndex: 'actualPay',
      ifShow: planType !== '承建',
      width: 150,
    },
    {
      title: '合同总额',
      dataIndex: 'contractAmount',
      ifShow: planType === '承建',
      width: 150,
    },
    {
      title: year + '年之前完成总产值(不包含' + year + '年)',
      dataIndex: 'outputValue',
      ifShow: planType === '承建',
      width: 150,
    },
    {
      title: year + '年计划完成产值',
      dataIndex: 'planCompleteOutputValue',
      ifShow: planType === '承建',
      width: 150,
    },
    {
      title: year + '年实际完成产值',
      dataIndex: 'actualOutputValue',
      ifShow: planType === '承建',
      width: 150,
    },
    {
      title: '建设性质',
      dataIndex: 'attribute',
      width: 150,
      ifShow: true,
    },
    {
      title: '开工时间',
      dataIndex: 'beginTime',
      width: 150,
      ifShow: true,
    },
    {
      title: '竣工时间',
      dataIndex: 'endTime',
      width: 150,
      ifShow: true,
    },
    {
      title: year + '年底形象季度',
      dataIndex: 'completionSchedule',
      width: 150,
      ifShow: true,
    },
    {
      title: '实施主体',
      dataIndex: 'implementingEntity',
      width: 150,
      ifShow: true,
    },
    {
      title: '合同方式',
      dataIndex: 'contract',
      ifShow: planType === '承建',
      width: 150,
    },
    {
      title: '项目主管部门',
      dataIndex: 'competentDepartment',
      ifShow: planType != '承建',
      width: 150,
    },
    {
      title: '备注',
      dataIndex: 'completionRemarks',
      width: 150,
      ifShow: true,
    },
  ];

  const filterColum = column.filter((item) => item.ifShow);
  return filterColum;
}
