import { BasicColumn, FormSchema } from '@/components/Table';
import { useUserStore } from '@/store/modules/user';

const deptId = useUserStore().userInfo.deptId;
//主模块-安全隐患列表页
export const formSchema: FormSchema[] = [
  // {
  //   field: 'fillingPeriod',
  //   labelWidth: '140px',
  //   label: '填报周期',
  //   required: true,
  //   component: 'DatePicker',
  //   componentProps: {
  //     placeholder: '填报周期',
  //     style: { width: '100%' },
  //     valueFormat: 'YYYY-MM-DD',
  //     format: 'YYYY-MM-DD',
  //   },
  // },
  {
    field: 'year',
    label: '年份',
    component: 'DatePicker',
    required: true,
    componentProps: {
      placeholder: '年份',
      picker: 'year',
      valueFormat: 'YYYY',
      format: 'YYYY',
      style: {
        width: '100%',
      },
    },
    colProps: { span: 11, offset: 1 },
  },
  {
    field: 'quarter',
    label: '季度',
    required: true,
    component: 'Select',
    componentProps: {
      placeholder: '季度',
      options: [
        {
          label: '第一季度',
          value: '第一季度',
        },
        {
          label: '第二季度',
          value: '第二季度',
        },
        {
          label: '第三季度',
          value: '第三季度',
        },
        {
          label: '第四季度',
          value: '第四季度',
        },
      ],
    },
    colProps: { span: 11, offset: 1 },
  },
  // {
  //   label: '公司名称',
  //   field: 'companyName',
  //   labelWidth: 150,
  // },
  {
    label: '隐患描述',
    field: 'describe',
    labelWidth: '140px',
    required: true,
    component: 'Input',
  },
  {
    label: '隐患级别',
    labelWidth: '140px',
    field: 'level',
    required: true,
    component: 'Input',
  },
  {
    label: '计划费用(万元)',
    labelWidth: '140px',
    field: 'planCost',
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '实际费用(万元)',
    labelWidth: '140px',
    field: 'actualCost',
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    field: 'actualTime',
    labelWidth: '140px',
    label: '检查时间',
    required: true,
    component: 'DatePicker',
    componentProps: {
      placeholder: '选择实际时间',
      style: { width: '100%' },
      valueFormat: 'YYYY-MM-DD',
      format: 'YYYY-MM-DD',
    },
  },
  {
    field: 'planTime',
    labelWidth: '140px',
    label: '隐患治理完成时间',
    required: true,
    component: 'DatePicker',
    componentProps: {
      placeholder: '选择计划时间',
      style: { width: '100%' },
      valueFormat: 'YYYY-MM-DD',
      format: 'YYYY-MM-DD',
    },
  },
  {
    label: '隐患后的评估情况',
    labelWidth: '140px',
    field: 'assessmentSituation',
    required: true,
    component: 'Input',
  },
  {
    label: '责任人',
    labelWidth: '140px',
    field: 'responsiblePerson',
    required: true,
    component: 'Input',
  },
];
export const columnsDate: BasicColumn[] = [
  {
    title: '公司名称',
    dataIndex: 'companyName',
    width: 150,
    ifShow: deptId === '100',
    fixed: 'left',
    customCell: (_, any) => ({
      rowSpan: _.companyNamerowSpan,
    }),
    // slots: { customRender: 'companyName' },
  },
  // {
  //   title: '填报周期',
  //   dataIndex: 'fillingPeriod',
  //   width: 150,
  // },
  {
    title: '隐患描述',
    dataIndex: 'describe',
    width: 150,
  },
  {
    title: '年份',
    dataIndex: 'year',
    width: 150,
  },
  {
    title: '季度',
    dataIndex: 'quarter',
    width: 150,
  },
  {
    title: '隐患级别',
    dataIndex: 'level',
    width: 150,
  },
  {
    title: '计划费用(万元)',
    dataIndex: 'planCost',
    width: 180,
  },
  {
    title: '实际费用(万元)',
    dataIndex: 'actualCost',
    width: 180,
  },
  {
    title: '计划时间',
    dataIndex: 'planTime',
    width: 180,
  },
  {
    title: '实际时间',
    dataIndex: 'actualTime',
    width: 180,
  },
  {
    title: '隐患治理后的评估情况',
    dataIndex: 'assessmentSituation',
    width: 180,
  },
  {
    title: '责任人',
    dataIndex: 'responsiblePerson',
    width: 180,
  },
  {
    title: '操作',
    dataIndex: 'action',
    width: 180,
    slots: { customRender: 'action' },
  },
];

export const searchFormSchemaDate: FormSchema[] = [
  {
    field: 'year',
    label: '',
    component: 'DatePicker',
    componentProps: {
      placeholder: '选择填报周期',
      picker: 'year',
      style: { width: '100%' },
      valueFormat: 'YYYY',
      format: 'YYYY',
    },
    colProps: { span: 4 },
  },
  {
    field: 'quarter',
    label: '',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '第一季度',
          value: '第一季度',
        },
        {
          label: '第二季度',
          value: '第二季度',
        },
        {
          label: '第三季度',
          value: '第三季度',
        },
        {
          label: '第四季度',
          value: '第四季度',
        },
      ],
      placeholder: '季度',
    },
    colProps: { span: 4 },
  },
  {
    field: 'companyName',
    label: '',
    component: 'Select',
    ifShow: deptId === '100',
    componentProps: {
      placeholder: '公司名称',
      options: [
        {
          label: '公司名称',
          value: '公司名称',
          key: '公司名称',
        },
      ],
    },
    colProps: { span: 4 },
  },
];
