import { FormSchema, BasicColumn, FormProps } from '@/components/Table';

export const searchFormSchema: FormSchema[] = [
  {
    field: 'projecName',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '输入搜索关键词',
    },
    colProps: { span: 4 },
  },
  {
    field: 'constructionMode',
    component: 'RadioButtonGroup',
    colProps: {
      span: 6,
    },
    componentProps: {
      options: [
        {
          label: '全部项目',
          value: undefined,
        },
        {
          label: '自建',
          value: '自建',
        },
        {
          label: '委托建设',
          value: '委托建设',
        },
        {
          label: '代建',
          value: '代建',
        },
        {
          label: '承建',
          value: '承建',
        },
      ],
    },
  },
  {
    field: 'isReserveProject',
    component: 'Checkbox',
    colProps: {
      span: 2,
    },
    renderComponentContent: '储备项目',
  },
  {
    field: 'ImplementingEntity',
    label: '',
    component: 'Select',
    componentProps: {
      placeholder: '实施主体',
      options: [
        {
          label: '了解产品',
          value: '了解产品',
          key: '了解产品',
        },
        {
          label: '正在跟进',
          value: '正在跟进',
          key: '正在跟进',
        },
        {
          label: '正在试用',
          value: '正在试用',
          key: '正在试用',
        },
        {
          label: '准备购买',
          value: '准备购买',
          key: '准备购买',
        },
        {
          label: '准备付款',
          value: '准备付款',
          key: '准备付款',
        },
        {
          label: '已经购买',
          value: '已经购买',
          key: '已经购买',
        },
        {
          label: '暂时闲置',
          value: '暂时闲置',
          key: '暂时闲置',
        },
      ],
    },
    colProps: { span: 3 },
  },
  {
    field: 'projectType',
    label: '',
    component: 'Select',
    componentProps: {
      placeholder: '项目类型',
      options: [
        {
          label: '公共设施配套类',
          value: '公共设施配套类',
          key: '公共设施配套类',
        },
        {
          label: '基础设施类',
          value: '基础设施类',
          key: '基础设施类',
        },
        {
          label: '产业载体类',
          value: '产业载体类',
          key: '产业载体类',
        },
        {
          label: '房地产类',
          value: '房地产类',
          key: '房地产类',
        },
        {
          label: '存量盘活类',
          value: '存量盘活类',
          key: '存量盘活类',
        },
        {
          label: '其他类（零星工程)',
          value: '其他类（零星工程)',
          key: '其他类（零星工程)',
        },
      ],
    },
    colProps: { span: 3 },
  },
];

export const columns: BasicColumn[] = [
  {
    title: '基本信息',
    dataIndex: 'projectName',
    width: 180,
  },
  {
    title: '实施主体',
    dataIndex: 'implementingEntity',
    width: 180,
  },
  {
    title: '建设模式',
    dataIndex: 'constructionMode',
    width: 200,
  },
  {
    title: '建设地点',
    dataIndex: 'constructionSite',
    width: 180,
  },
  {
    title: '项目类型',
    dataIndex: 'projectType',
    width: 180,
  },
  {
    title: '资金来源',
    dataIndex: 'fundingSource',
    width: 180,
  },
  {
    title: '建设目的及项目功能',
    dataIndex: 'constructionPurpose',
    width: 180,
  },
  {
    title: '建设规模',
    dataIndex: 'constructionScale',
    width: 180,
  },
];
export const tabList = [
  {
    key: '1',
    tab: '投资计划',
    component: 'InvestmentPlan',
  },
  {
    key: '2',
    tab: '计划完成情况',
    component: 'performance',
  },
  {
    key: '3',
    tab: '年度资金计划',
    component: 'annualPlan',
  },
  {
    key: '4',
    tab: '月度资金计划',
    component: 'monthlyPlan',
  },
  {
    key: '5',
    tab: '已竣工验收项目陈欠资金计划',
    component: 'completed',
  },
  {
    key: '6',
    tab: '招标计划',
    component: 'biddingPlan',
  },
  {
    key: '7',
    tab: '招标管理',
    component: 'biddingManagement',
  },
  {
    key: '8',
    tab: '结算管理',
    component: 'settlementManagement',
  },
  {
    key: '9',
    tab: '变更签证管理',
    component: 'changeSignature',
  },
  {
    key: '10',
    tab: '安全隐患管理',
    component: 'potentialSafety',
  },
  {
    key: '11',
    tab: '安全教育培训',
    component: 'safetyEducation',
  },
  {
    key: '12',
    tab: '合同管理',
    component: 'contract',
  },
  {
    key: '13',
    tab: '附件记录',
    component: 'annex',
  },
  {
    key: '14',
    tab: '更新记录',
    component: 'updateRecords',
  },
];

// 7-招标管理详情
export const biddingManagementFormSchema: FormSchema[] = [
  {
    field: 'tenderYear',
    labelWidth: '140px',
    label: '填报年份',
    required: false,
    component: 'Input',
  },
  {
    label: '项目名称',
    field: 'projectName',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '立项投资额',
    field: 'uniqueProjectCount',
    labelWidth: '140px',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '资金来源',
    field: 'fundingSource',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '招标类型',
    labelWidth: '140px',
    field: 'biddingType',
    required: false,
    component: 'Input',
  },
  {
    label: '招标内容',
    labelWidth: '140px',
    field: 'tenderContent',
    required: false,
    component: 'Input',
  },
  {
    label: '招标控制',
    labelWidth: '140px',
    field: 'controlPrice',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '建设模式',
    labelWidth: '140px',
    field: 'constructionMode',
    required: false,
    component: 'Input',
  },
  {
    label: '招标采购方式',
    labelWidth: '140px',
    field: 'procurementMethod',
    required: false,
    component: 'Input',
  },
  {
    label: '招标完成情况',
    labelWidth: '140px',
    field: 'completionStatus',
    required: false,
    component: 'Input',
  },
  {
    label: '开标时间',
    labelWidth: '140px',
    field: 'openingTime',
    required: false,
    component: 'Input',
  },
  {
    label: '中标单位',
    labelWidth: '140px',
    field: 'winningBidder',
    required: false,
    component: 'Input',
  },
  {
    label: '中标金额',
    labelWidth: '140px',
    field: 'winningAmount',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '中标工期',
    labelWidth: '140px',
    field: 'winningPeriod',
    required: false,
    component: 'Input',
  },
  {
    label: '合同签订日期',
    labelWidth: '140px',
    field: 'signingDate',
    required: false,
    component: 'Input',
  },
  {
    label: '会议纪要',
    labelWidth: '140px',
    field: 'meetingMinute',
    required: false,
    component: 'Input',
  },
  {
    label: '招标信息发布渠道',
    labelWidth: '140px',
    field: 'releaseChannels',
    required: false,
    component: 'Input',
  },
  {
    label: '招标公告发布网址\n' + '\n' + '（仅限公开招标项目）',
    labelWidth: '140px',
    field: 'publishWebsite',
    required: false,
    component: 'Input',
  },
  {
    label: '中标结果公示网址\n' + '\n' + '（仅限公开招标项目）',
    labelWidth: '140px',
    field: 'publicityWebsite',
    required: false,
    component: 'Input',
  },
  {
    label: '是否存在投诉举报情况',
    labelWidth: '140px',
    field: 'isReportingSituation',
    required: false,
    component: 'Input',
  },
  {
    label: '投诉举报解决处理情况',
    labelWidth: '140px',
    field: 'handSituation',
    required: false,
    component: 'Input',
  },
  {
    label: '备注',
    labelWidth: '140px',
    field: 'remark',
    required: false,
    component: 'Input',
  },
];
//招标管理-查询条件
export function getFormConfig(): Partial<FormProps> {
  return {
    labelWidth: 100,
    schemas: [
      {
        field: 'tenderYear',
        label: '填报年份',
        component: 'DatePicker',
        componentProps: {
          placeholder: '选择填报年份',
          picker: 'year',
          valueFormat: 'YYYY',
          format: 'YYYY',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '填报季度',
        field: 'biddingQuarter',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '第一季度',
              value: '第一季度',
              key: '第一季度',
            },
            {
              label: '第二季度',
              value: '第二季度',
              key: '第二季度',
            },
            {
              label: '第三季度',
              value: '第三季度',
              key: '第三季度',
            },
            {
              label: '第四季度',
              value: '第四季度',
              key: '第四季度',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '项目名称',
        field: 'projectName',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '立项投资额',
        field: 'investmentAmount',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '资金来源',
        field: 'fundingSource',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '自筹',
              value: '自筹',
              key: '自筹',
            },
            {
              label: '财政资金',
              value: '财政资金',
              key: '财政资金',
            },
            {
              label: '专项债',
              value: '专项债',
              key: '专项债',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标类型',
        field: 'biddingType',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '施工',
              value: '施工',
            },
            {
              label: '监理',
              value: '监理',
            },
            {
              label: '设计',
              value: '设计',
            },
            {
              label: '图审',
              value: '图审',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标内容',
        field: 'tenderContent',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标控制',
        field: 'controlPrice',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '建设模式',
        field: 'constructionMode',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '全部项目',
              value: undefined,
            },
            {
              label: '自建',
              value: '自建',
            },
            {
              label: '委托建设',
              value: '委托建设',
            },
            {
              label: '代建',
              value: '代建',
            },
            {
              label: '承建',
              value: '承建',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标采购方式',
        field: 'procurementMethod',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '建委招标',
              value: '建委招标',
            },
            {
              label: '平台招标',
              value: '平台招标',
            },
            {
              label: '邀标比选',
              value: '邀标比选',
            },
            {
              label: '直接委托',
              value: '直接委托',
            },
            {
              label: '评分定离',
              value: '评分定离',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标完成情况',
        field: 'completionStatus',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '开标时间',
        field: 'openingTime',
        labelWidth: '140px',
        component: 'DatePicker',
        componentProps: {
          picker: 'date',
          valueFormat: 'YYYY-MM-DD',
          format: 'YYYY-MM-DD',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '中标单位',
        field: 'winningBidder',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '中标金额',
        field: 'winningAmount',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '中标工期',
        field: 'winningPeriod',
        labelWidth: '140px',
        component: 'Input',
      },
      {
        label: '合同签订日期',
        field: 'signingDate',
        labelWidth: '140px',
        component: 'DatePicker',
        componentProps: {
          picker: 'date',
          valueFormat: 'YYYY-MM-DD',
          format: 'YYYY-MM-DD',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '会议纪要',
        field: 'meetingMinute',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标信息发布渠道',
        field: 'releaseChannels',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '中国招标投标公共服务平台',
              value: '中国招标投标公共服务平台',
            },
            {
              label: '公司OA和公众号',
              value: '公司OA和公众号',
            },
            {
              label: '天津市公共资源交易中心',
              value: '天津市公共资源交易中心',
            },
            {
              label: '邮箱',
              value: '邮箱',
            },
            {
              label: '其他',
              value: '其他',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标公告发布网址（仅限公开招标项目）',
        field: 'publishWebsite',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '中标结果公示网址（仅限公开招标项目）',
        field: 'publicityWebsite',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '是否存在投诉举报情况',
        field: 'isReportingSituation',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '是',
              value: '是',
              key: '是',
            },
            {
              label: '否',
              value: '否',
              key: '否',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '投诉举报解决处理情况',
        field: 'handSituation',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '备注',
        field: 'remark',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
    ],
  };
}
