import { FormSchema, BasicColumn, FormProps } from '@/components/Table';
import { uploadApi } from '@/api/sys/upload';

export const searchFormSchema: FormSchema[] = [
  {
    field: 'projecName',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '输入搜索关键词',
    },
    colProps: { span: 4 },
  },
  {
    field: 'constructionMode',
    component: 'RadioButtonGroup',
    colProps: {
      span: 6,
    },
    componentProps: {
      options: [
        {
          label: '全部项目',
          value: undefined,
        },
        {
          label: '自建',
          value: '自建',
        },
        {
          label: '委托建设',
          value: '委托建设',
        },
        {
          label: '代建',
          value: '代建',
        },
        {
          label: '承建',
          value: '承建',
        },
      ],
    },
  },
  {
    field: 'isReserveProject',
    component: 'Checkbox',
    colProps: {
      span: 2,
    },
    renderComponentContent: '储备项目',
  },
  {
    field: 'ImplementingEntity',
    label: '',
    component: 'Select',
    componentProps: {
      placeholder: '实施主体',
      options: [
        {
          label: '了解产品',
          value: '了解产品',
          key: '了解产品',
        },
        {
          label: '正在跟进',
          value: '正在跟进',
          key: '正在跟进',
        },
        {
          label: '正在试用',
          value: '正在试用',
          key: '正在试用',
        },
        {
          label: '准备购买',
          value: '准备购买',
          key: '准备购买',
        },
        {
          label: '准备付款',
          value: '准备付款',
          key: '准备付款',
        },
        {
          label: '已经购买',
          value: '已经购买',
          key: '已经购买',
        },
        {
          label: '暂时闲置',
          value: '暂时闲置',
          key: '暂时闲置',
        },
      ],
    },
    colProps: { span: 3 },
  },
  {
    field: 'projectType',
    label: '',
    component: 'Select',
    componentProps: {
      placeholder: '项目类型',
      options: [
        {
          label: '公共设施配套类',
          value: '公共设施配套类',
          key: '公共设施配套类',
        },
        {
          label: '基础设施类',
          value: '基础设施类',
          key: '基础设施类',
        },
        {
          label: '产业载体类',
          value: '产业载体类',
          key: '产业载体类',
        },
        {
          label: '房地产类',
          value: '房地产类',
          key: '房地产类',
        },
        {
          label: '存量盘活类',
          value: '存量盘活类',
          key: '存量盘活类',
        },
        {
          label: '其他类（零星工程)',
          value: '其他类（零星工程)',
          key: '其他类（零星工程)',
        },
      ],
    },
    colProps: { span: 3 },
  },
];

export const columns: BasicColumn[] = [
  {
    title: '基本信息',
    dataIndex: 'projectName',
    width: 180,
  },
  {
    title: '实施主体',
    dataIndex: 'implementingEntity',
    width: 180,
  },
  {
    title: '建设模式',
    dataIndex: 'constructionMode',
    width: 200,
  },
  {
    title: '建设地点',
    dataIndex: 'constructionSite',
    width: 180,
  },
  {
    title: '项目类型',
    dataIndex: 'projectType',
    width: 180,
  },
  {
    title: '资金来源',
    dataIndex: 'fundingSource',
    width: 180,
  },
  {
    title: '建设目的及项目功能',
    dataIndex: 'constructionPurpose',
    width: 180,
  },
  {
    title: '建设规模',
    dataIndex: 'constructionScale',
    width: 180,
  },
];
export const tabList = [
  {
    key: '1',
    tab: '投资计划',
    component: 'InvestmentPlan',
  },
  {
    key: '2',
    tab: '计划完成情况',
    component: 'performance',
  },
  {
    key: '3',
    tab: '年度资金计划',
    component: 'annualPlan',
  },
  {
    key: '4',
    tab: '月度资金计划',
    component: 'monthlyPlan',
  },
  {
    key: '5',
    tab: '已竣工验收项目陈欠资金计划',
    component: 'completed',
  },
  {
    key: '6',
    tab: '招标计划',
    component: 'biddingPlan',
  },
  {
    key: '7',
    tab: '招标管理',
    component: 'biddingManagement',
  },
  {
    key: '8',
    tab: '结算管理',
    component: 'settlementManagement',
  },
  {
    key: '9',
    tab: '变更签证管理',
    component: 'changeSignature',
  },
  {
    key: '10',
    tab: '安全隐患管理',
    component: 'potentialSafety',
  },
  {
    key: '11',
    tab: '安全教育培训',
    component: 'safetyEducation',
  },
  {
    key: '12',
    tab: '合同管理',
    component: 'contract',
  },
  {
    key: '13',
    tab: '附件记录',
    component: 'annex',
  },
  {
    key: '14',
    tab: '更新记录',
    component: 'updateRecords',
  },
];

// 6-招标计划详情
export const biddingFormSchema: FormSchema[] = [
  {
    field: 'tenderYear',
    labelWidth: '140px',
    label: '填报年份',
    required: false,
    component: 'Input',
  },
  {
    label: '项目名称',
    field: 'projectName',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '立项主体',
    field: 'projectInitiator',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '资金来源',
    field: 'fundingSource',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '立项投资额',
    labelWidth: '140px',
    field: 'investmentAmount',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '招标类型',
    labelWidth: '140px',
    field: 'biddingType',
    required: false,
    component: 'Input',
  },
  {
    label: '招标内容',
    labelWidth: '140px',
    field: 'tenderContent',
    required: false,
    component: 'Input',
  },
  {
    label: '预计控制价',
    labelWidth: '140px',
    field: 'controlPrice',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '计划工期',
    labelWidth: '140px',
    field: 'plannedPeriod',
    required: false,
    component: 'Input',
  },
  {
    label: '招标方式',
    labelWidth: '140px',
    field: 'biddingMethod',
    required: false,
    component: 'Input',
  },
  {
    label: '计划招标周期',
    labelWidth: '140px',
    field: 'biddingPeriod',
    required: false,
    component: 'Input',
  },
  {
    label: '备注',
    labelWidth: '140px',
    field: 'remark',
    required: false,
    component: 'Input',
  },
];
//招标计划-查询条件
export function getFormConfig(): Partial<FormProps> {
  return {
    labelWidth: 100,
    schemas: [
      {
        field: 'tenderYear',
        label: '填报年份',
        component: 'DatePicker',
        componentProps: {
          placeholder: '选择填报年份',
          picker: 'year',
          valueFormat: 'YYYY',
          format: 'YYYY',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '填报季度',
        field: 'biddingQuarter',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '第一季度',
              value: '第一季度',
              key: '第一季度',
            },
            {
              label: '第二季度',
              value: '第二季度',
              key: '第二季度',
            },
            {
              label: '第三季度',
              value: '第三季度',
              key: '第三季度',
            },
            {
              label: '第四季度',
              value: '第四季度',
              key: '第四季度',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '项目名称',
        field: 'projectName',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '立项主体',
        field: 'projectInitiator',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '资金来源',
        field: 'fundingSource',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '自筹',
              value: '自筹',
              key: '自筹',
            },
            {
              label: '财政资金',
              value: '财政资金',
              key: '财政资金',
            },
            {
              label: '专项债',
              value: '专项债',
              key: '专项债',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '立项投资额',
        field: 'investmentAmount',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标类型',
        field: 'biddingType',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '施工',
              value: '施工',
            },
            {
              label: '监理',
              value: '监理',
            },
            {
              label: '设计',
              value: '设计',
            },
            {
              label: '图审',
              value: '图审',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标内容',
        field: 'tenderContent',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '预计控制价',
        field: 'controlPrice',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标方式',
        field: 'biddingMethod',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '建委招标',
              value: '建委招标',
            },
            {
              label: '平台招标',
              value: '平台招标',
            },
            {
              label: '邀标比选',
              value: '邀标比选',
            },
            {
              label: '直接委托',
              value: '直接委托',
            },
            {
              label: '评分定离',
              value: '评分定离',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '备注',
        field: 'remark',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
    ],
  };
}
