import { FormSchema, BasicColumn, FormProps } from '@/components/Table';
import { uploadApi } from '@/api/sys/upload';
// 5-已竣工详情
export const formSchema: FormSchema[] = [
  {
    field: 'filingCycle',
    labelWidth: '140px',
    label: '填报周期',
    required: false,
    component: 'Input',
  },
  {
    label: '公司名称',
    field: 'company',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '项目名称',
    field: 'projectName',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '项目类型',
    field: 'projectType',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '建设地点',
    field: 'constructionSite',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '合同额',
    field: 'contractAmount',
    labelWidth: '140px',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '结算金额',
    field: 'completionSettlement',
    labelWidth: '140px',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '立项总投资合计',
    labelWidth: '140px',
    field: 'projectApproval',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '上一年底前累计实付额',
    labelWidth: '140px',
    field: 'totalActualPay',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '年资金计划额合计',
    labelWidth: '140px',
    field: 'totalValue',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '专项拨款合计',
    labelWidth: '140px',
    field: 'totalSpecialBond',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '银行融资合计',
    labelWidth: '140px',
    field: 'totalBankFinancing',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '自有资金合计',
    labelWidth: '140px',
    field: 'totalOwnFunds',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '当年资金缺口',
    labelWidth: '140px',
    field: 'fundingGap',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '资金执行情况-计划额',
    labelWidth: '140px',
    field: 'annualFund',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '资金执行情况-实付额',
    labelWidth: '140px',
    field: 'actualPay',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '项目主管部门',
    labelWidth: '140px',
    field: 'competentDepartment',
    required: false,
    component: 'Input',
  },
  {
    label: '备注',
    labelWidth: '140px',
    field: 'remarks',
    required: false,
    component: 'Input',
  },
];
export const exportUrl = '/pro/export/overdueFunds';

//查询条件
export function getFormConfig(): Partial<FormProps> {
  return {
    labelWidth: 100,
    schemas: [
      {
        field: 'filingCycle',
        label: '填报周期',
        component: 'DatePicker',
        componentProps: {
          placeholder: '选择填报周期',
          picker: 'year',
          valueFormat: 'YYYY',
          format: 'YYYY',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '公司名称',
        field: 'company',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '项目名称',
        field: 'projectName',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '建设地点',
        field: 'constructionSite',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '立项总投资合计',
        field: 'projectApproval',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '上一年底前累计实付额',
        field: 'totalActualPay',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '年资金计划额合计',
        field: 'totalValue',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '专项拨款合计',
        field: 'totalSpecialBond',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '银行融资合计',
        field: 'totalBankFinancing',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '自有资金合计',
        field: 'totalOwnFunds',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '当年资金缺口',
        field: 'fundingGap',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '项目主管部门',
        field: 'competentDepartment',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '备注',
        field: 'remarks',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
    ],
  };
}

export const searchFormSchema: FormSchema[] = [
  {
    field: 'projecName',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '输入搜索关键词',
    },
    colProps: { span: 4 },
  },
  {
    field: 'constructionMode',
    component: 'RadioButtonGroup',
    colProps: {
      span: 6,
    },
    componentProps: {
      options: [
        {
          label: '全部项目',
          value: undefined,
        },
        {
          label: '自建',
          value: '自建',
        },
        {
          label: '委托建设',
          value: '委托建设',
        },
        {
          label: '代建',
          value: '代建',
        },
        {
          label: '承建',
          value: '承建',
        },
      ],
    },
  },
  {
    field: 'isReserveProject',
    component: 'Checkbox',
    colProps: {
      span: 2,
    },
    renderComponentContent: '储备项目',
  },
  {
    field: 'ImplementingEntity',
    label: '',
    component: 'Select',
    componentProps: {
      placeholder: '实施主体',
      options: [
        {
          label: '了解产品',
          value: '了解产品',
          key: '了解产品',
        },
        {
          label: '正在跟进',
          value: '正在跟进',
          key: '正在跟进',
        },
        {
          label: '正在试用',
          value: '正在试用',
          key: '正在试用',
        },
        {
          label: '准备购买',
          value: '准备购买',
          key: '准备购买',
        },
        {
          label: '准备付款',
          value: '准备付款',
          key: '准备付款',
        },
        {
          label: '已经购买',
          value: '已经购买',
          key: '已经购买',
        },
        {
          label: '暂时闲置',
          value: '暂时闲置',
          key: '暂时闲置',
        },
      ],
    },
    colProps: { span: 3 },
  },
  {
    field: 'projectType',
    label: '',
    component: 'Select',
    componentProps: {
      placeholder: '项目类型',
      options: [
        {
          label: '公共设施配套类',
          value: '公共设施配套类',
          key: '公共设施配套类',
        },
        {
          label: '基础设施类',
          value: '基础设施类',
          key: '基础设施类',
        },
        {
          label: '产业载体类',
          value: '产业载体类',
          key: '产业载体类',
        },
        {
          label: '房地产类',
          value: '房地产类',
          key: '房地产类',
        },
        {
          label: '存量盘活类',
          value: '存量盘活类',
          key: '存量盘活类',
        },
        {
          label: '其他类（零星工程)',
          value: '其他类（零星工程)',
          key: '其他类（零星工程)',
        },
      ],
    },
    colProps: { span: 3 },
  },
];

export const columns: BasicColumn[] = [
  {
    title: '基本信息',
    dataIndex: 'projectName',
    width: 180,
  },
  {
    title: '实施主体',
    dataIndex: 'implementingEntity',
    width: 180,
  },
  {
    title: '建设模式',
    dataIndex: 'constructionMode',
    width: 200,
  },
  {
    title: '建设地点',
    dataIndex: 'constructionSite',
    width: 180,
  },
  {
    title: '项目类型',
    dataIndex: 'projectType',
    width: 180,
  },
  {
    title: '资金来源',
    dataIndex: 'fundingSource',
    width: 180,
  },
  {
    title: '建设目的及项目功能',
    dataIndex: 'constructionPurpose',
    width: 180,
  },
  {
    title: '建设规模',
    dataIndex: 'constructionScale',
    width: 180,
  },
];
export const tabList = [
  {
    key: '1',
    tab: '投资计划',
    component: 'InvestmentPlan',
  },
  {
    key: '2',
    tab: '计划完成情况',
    component: 'performance',
  },
  {
    key: '3',
    tab: '年度资金计划',
    component: 'annualPlan',
  },
  {
    key: '4',
    tab: '月度资金计划',
    component: 'monthlyPlan',
  },
  {
    key: '5',
    tab: '已竣工验收项目陈欠资金计划',
    component: 'completed',
  },
  {
    key: '6',
    tab: '招标计划',
    component: 'biddingPlan',
  },
  {
    key: '7',
    tab: '招标管理',
    component: 'biddingManagement',
  },
  {
    key: '8',
    tab: '结算管理',
    component: 'settlementManagement',
  },
  {
    key: '9',
    tab: '变更签证管理',
    component: 'changeSignature',
  },
  {
    key: '10',
    tab: '安全隐患管理',
    component: 'potentialSafety',
  },
  {
    key: '11',
    tab: '安全教育培训',
    component: 'safetyEducation',
  },
  {
    key: '12',
    tab: '合同管理',
    component: 'contract',
  },
  {
    key: '13',
    tab: '附件记录',
    component: 'annex',
  },
  {
    key: '14',
    tab: '更新记录',
    component: 'updateRecords',
  },
];
