import { FormSchema, BasicColumn } from '@/components/Table';

//安全隐患管理详情抽屉
export const formSchema: FormSchema[] = [
  {
    label: '填报周期',
    field: 'fillingPeriod',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '隐患描述',
    field: 'describe',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '隐患级别',
    field: 'level',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '计划费用',
    field: 'planCost',
    labelWidth: '140px',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '实际费用',
    field: 'actualCost',
    labelWidth: '140px',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '计划时间',
    field: 'planTime',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '实际时间',
    field: 'actualTime',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '隐患治理后的评估情况',
    field: 'assessmentSituation',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '责任人',
    field: 'responsiblePerson',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'projecName',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '输入搜索关键词',
    },
    colProps: { span: 4 },
  },
  {
    field: 'constructionMode',
    component: 'RadioButtonGroup',
    colProps: {
      span: 6,
    },
    componentProps: {
      options: [
        {
          label: '全部项目',
          value: undefined,
        },
        {
          label: '自建',
          value: '自建',
        },
        {
          label: '委托建设',
          value: '委托建设',
        },
        {
          label: '代建',
          value: '代建',
        },
        {
          label: '承建',
          value: '承建',
        },
      ],
    },
  },
  {
    field: 'isReserveProject',
    component: 'Checkbox',
    colProps: {
      span: 2,
    },
    renderComponentContent: '储备项目',
  },
  {
    field: 'ImplementingEntity',
    label: '',
    component: 'Select',
    componentProps: {
      placeholder: '实施主体',
      options: [
        {
          label: '了解产品',
          value: '了解产品',
          key: '了解产品',
        },
        {
          label: '正在跟进',
          value: '正在跟进',
          key: '正在跟进',
        },
        {
          label: '正在试用',
          value: '正在试用',
          key: '正在试用',
        },
        {
          label: '准备购买',
          value: '准备购买',
          key: '准备购买',
        },
        {
          label: '准备付款',
          value: '准备付款',
          key: '准备付款',
        },
        {
          label: '已经购买',
          value: '已经购买',
          key: '已经购买',
        },
        {
          label: '暂时闲置',
          value: '暂时闲置',
          key: '暂时闲置',
        },
      ],
    },
    colProps: { span: 3 },
  },
  {
    field: 'projectType',
    label: '',
    component: 'Select',
    componentProps: {
      placeholder: '项目类型',
      options: [
        {
          label: '公共设施配套类',
          value: '公共设施配套类',
          key: '公共设施配套类',
        },
        {
          label: '基础设施类',
          value: '基础设施类',
          key: '基础设施类',
        },
        {
          label: '产业载体类',
          value: '产业载体类',
          key: '产业载体类',
        },
        {
          label: '房地产类',
          value: '房地产类',
          key: '房地产类',
        },
        {
          label: '存量盘活类',
          value: '存量盘活类',
          key: '存量盘活类',
        },
        {
          label: '其他类（零星工程)',
          value: '其他类（零星工程)',
          key: '其他类（零星工程)',
        },
      ],
    },
    colProps: { span: 3 },
  },
];

export const columns: BasicColumn[] = [
  {
    title: '基本信息',
    dataIndex: 'projectName',
    width: 180,
  },
  {
    title: '实施主体',
    dataIndex: 'implementingEntity',
    width: 180,
  },
  {
    title: '建设模式',
    dataIndex: 'constructionMode',
    width: 200,
  },
  {
    title: '建设地点',
    dataIndex: 'constructionSite',
    width: 180,
  },
  {
    title: '项目类型',
    dataIndex: 'projectType',
    width: 180,
  },
  {
    title: '资金来源',
    dataIndex: 'fundingSource',
    width: 180,
  },
  {
    title: '建设目的及项目功能',
    dataIndex: 'constructionPurpose',
    width: 180,
  },
  {
    title: '建设规模',
    dataIndex: 'constructionScale',
    width: 180,
  },
];
export const tabList = [
  {
    key: '1',
    tab: '投资计划',
    component: 'InvestmentPlan',
  },
  {
    key: '2',
    tab: '计划完成情况',
    component: 'performance',
  },
  {
    key: '3',
    tab: '年度资金计划',
    component: 'annualPlan',
  },
  {
    key: '4',
    tab: '月度资金计划',
    component: 'monthlyPlan',
  },
  {
    key: '5',
    tab: '已竣工验收项目陈欠资金计划',
    component: 'completed',
  },
  {
    key: '6',
    tab: '招标计划',
    component: 'biddingPlan',
  },
  {
    key: '7',
    tab: '招标管理',
    component: 'biddingManagement',
  },
  {
    key: '8',
    tab: '结算管理',
    component: 'settlementManagement',
  },
  {
    key: '9',
    tab: '变更签证管理',
    component: 'changeSignature',
  },
  {
    key: '10',
    tab: '安全隐患管理',
    component: 'potentialSafety',
  },
  {
    key: '11',
    tab: '安全教育培训',
    component: 'safetyEducation',
  },
  {
    key: '12',
    tab: '合同管理',
    component: 'contract',
  },
  {
    key: '13',
    tab: '附件记录',
    component: 'annex',
  },
  {
    key: '14',
    tab: '更新记录',
    component: 'updateRecords',
  },
];
export const searchExportFormSchema: FormSchema[] = [
  {
    field: 'fillingPeriod',
    label: '填报周期',
    component: 'DatePicker',
    componentProps: {
      placeholder: '填报周期',
      style: { width: '100%' },
      valueFormat: 'YYYY-MM-DD',
      format: 'YYYY-MM-DD',
    },
    colProps: {
      xl: 8,
      xxl: 4,
    },
  },
  {
    label: '隐患描述',
    field: 'describe',
    component: 'Input',
    colProps: {
      xl: 8,
      xxl: 4,
    },
  },
  {
    label: '隐患级别',
    field: 'level',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '一级',
          value: '一级',
        },
        {
          label: '二级',
          value: '二级',
        },
        {
          label: '三级',
          value: '三级',
        },
      ],
    },
    colProps: {
      xl: 8,
      xxl: 4,
    },
  },
  {
    label: '计划费用',
    field: 'planCost',
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
    colProps: {
      xl: 8,
      xxl: 4,
    },
  },
  {
    label: '实际费用',
    field: 'actualCost',
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
    colProps: {
      xl: 8,
      xxl: 4,
    },
  },
  {
    field: 'actualTime',
    label: '实际时间',
    component: 'DatePicker',
    componentProps: {
      placeholder: '选择实际时间',
      style: { width: '100%' },
      valueFormat: 'YYYY-MM-DD',
      format: 'YYYY-MM-DD',
    },
    colProps: {
      xl: 8,
      xxl: 4,
    },
  },
  {
    field: 'planTime',
    label: '计划时间',
    component: 'DatePicker',
    componentProps: {
      placeholder: '选择计划时间',
      style: { width: '100%' },
      valueFormat: 'YYYY-MM-DD',
      format: 'YYYY-MM-DD',
    },
    colProps: {
      xl: 8,
      xxl: 4,
    },
  },
  {
    label: '隐患后的评估情况',
    field: 'assessmentSituation',
    component: 'Input',
    colProps: {
      xl: 8,
      xxl: 4,
    },
  },
  {
    label: '责任人',
    field: 'responsiblePerson',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '责任人一',
          value: '责任人一',
        },
        {
          label: '责任人二',
          value: '责任人二',
        },
      ],
    },
    colProps: {
      xl: 8,
      xxl: 4,
    },
  },
];
