import { FormSchema, BasicColumn, FormProps } from '@/components/Table';
import { uploadApi } from '@/api/sys/upload';

//结算管理详情抽屉
export const formSchema: FormSchema[] = [
  {
    label: '填报周期',
    field: 'yearQuarter',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '立项投资额',
    field: 'projectInvestment',
    labelWidth: '140px',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '资金来源',
    field: 'fundingSource',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '招标方式',
    field: 'biddingMethod',
    labelWidth: '140px',
    required: false,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '建委招标',
          value: '1',
        },
        {
          label: '平台招标',
          value: '2',
        },
        {
          label: '邀标比选',
          value: '3',
        },
        {
          label: '直接委托',
          value: '4',
        },
        {
          label: '评分定离',
          value: '5',
        },
      ],
    },
  },
  {
    label: '合同类型',
    field: 'contracYpe',
    labelWidth: '140px',
    required: false,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '施工',
          value: '1',
        },
        {
          label: '监理',
          value: '2',
        },
        {
          label: '设计',
          value: '3',
        },
        {
          label: '图审',
          value: '4',
        },
      ],
    },
  },
  {
    label: '合同名称',
    field: 'contractName',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '甲方单位名称',
    field: 'firstPartyName',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '乙方单位名称',
    field: 'secondPartyName',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '合同形式',
    field: 'formOfContract',
    labelWidth: '140px',
    required: false,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '固定总价',
          value: '1',
        },
        {
          label: '固定单价',
          value: '2',
        },
        {
          label: '费率',
          value: '3',
        },
        {
          label: '其他',
          value: '4',
        },
      ],
    },
  },
  {
    label: '合同签订时间',
    field: 'contractSigningTime',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '竣工时间',
    field: 'closingTime',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '结算完成时间',
    field: 'closingTimeDatetime',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '合同金额',
    field: 'contractAmount',
    labelWidth: '140px',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '签证、变更金额',
    field: 'submittedForSettlement',
    labelWidth: '140px',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '结算报送金额',
    field: 'superContractScale',
    labelWidth: '140px',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '结算审定金额',
    field: 'sumOfMoney',
    labelWidth: '140px',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '结算审核金额超合同额比例',
    field: 'proportionContractAmount',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '会议纪要',
    field: 'meetingMinutes',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '备注',
    field: 'remark',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'projecName',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '输入搜索关键词',
    },
    colProps: { span: 4 },
  },
  {
    field: 'constructionMode',
    component: 'RadioButtonGroup',
    colProps: {
      span: 6,
    },
    componentProps: {
      options: [
        {
          label: '全部项目',
          value: undefined,
        },
        {
          label: '自建',
          value: '自建',
        },
        {
          label: '委托建设',
          value: '委托建设',
        },
        {
          label: '代建',
          value: '代建',
        },
        {
          label: '承建',
          value: '承建',
        },
      ],
    },
  },
  {
    field: 'isReserveProject',
    component: 'Checkbox',
    colProps: {
      span: 2,
    },
    renderComponentContent: '储备项目',
  },
  {
    field: 'ImplementingEntity',
    label: '',
    component: 'Select',
    componentProps: {
      placeholder: '实施主体',
      options: [
        {
          label: '了解产品',
          value: '了解产品',
          key: '了解产品',
        },
        {
          label: '正在跟进',
          value: '正在跟进',
          key: '正在跟进',
        },
        {
          label: '正在试用',
          value: '正在试用',
          key: '正在试用',
        },
        {
          label: '准备购买',
          value: '准备购买',
          key: '准备购买',
        },
        {
          label: '准备付款',
          value: '准备付款',
          key: '准备付款',
        },
        {
          label: '已经购买',
          value: '已经购买',
          key: '已经购买',
        },
        {
          label: '暂时闲置',
          value: '暂时闲置',
          key: '暂时闲置',
        },
      ],
    },
    colProps: { span: 3 },
  },
  {
    field: 'projectType',
    label: '',
    component: 'Select',
    componentProps: {
      placeholder: '项目类型',
      options: [
        {
          label: '公共设施配套类',
          value: '公共设施配套类',
          key: '公共设施配套类',
        },
        {
          label: '基础设施类',
          value: '基础设施类',
          key: '基础设施类',
        },
        {
          label: '产业载体类',
          value: '产业载体类',
          key: '产业载体类',
        },
        {
          label: '房地产类',
          value: '房地产类',
          key: '房地产类',
        },
        {
          label: '存量盘活类',
          value: '存量盘活类',
          key: '存量盘活类',
        },
        {
          label: '其他类（零星工程)',
          value: '其他类（零星工程)',
          key: '其他类（零星工程)',
        },
      ],
    },
    colProps: { span: 3 },
  },
];

export const columns: BasicColumn[] = [
  {
    title: '基本信息',
    dataIndex: 'projectName',
    width: 180,
  },
  {
    title: '实施主体',
    dataIndex: 'implementingEntity',
    width: 180,
  },
  {
    title: '建设模式',
    dataIndex: 'constructionMode',
    width: 200,
  },
  {
    title: '建设地点',
    dataIndex: 'constructionSite',
    width: 180,
  },
  {
    title: '项目类型',
    dataIndex: 'projectType',
    width: 180,
  },
  {
    title: '资金来源',
    dataIndex: 'fundingSource',
    width: 180,
  },
  {
    title: '建设目的及项目功能',
    dataIndex: 'constructionPurpose',
    width: 180,
  },
  {
    title: '建设规模',
    dataIndex: 'constructionScale',
    width: 180,
  },
];
export const tabList = [
  {
    key: '1',
    tab: '投资计划',
    component: 'InvestmentPlan',
  },
  {
    key: '2',
    tab: '计划完成情况',
    component: 'performance',
  },
  {
    key: '3',
    tab: '年度资金计划',
    component: 'annualPlan',
  },
  {
    key: '4',
    tab: '月度资金计划',
    component: 'monthlyPlan',
  },
  {
    key: '5',
    tab: '已竣工验收项目陈欠资金计划',
    component: 'completed',
  },
  {
    key: '6',
    tab: '招标计划',
    component: 'biddingPlan',
  },
  {
    key: '7',
    tab: '招标管理',
    component: 'biddingManagement',
  },
  {
    key: '8',
    tab: '结算管理',
    component: 'settlementManagement',
  },
  {
    key: '9',
    tab: '变更签证管理',
    component: 'changeSignature',
  },
  {
    key: '10',
    tab: '安全隐患管理',
    component: 'potentialSafety',
  },
  {
    key: '11',
    tab: '安全教育培训',
    component: 'safetyEducation',
  },
  {
    key: '12',
    tab: '合同管理',
    component: 'contract',
  },
  {
    key: '13',
    tab: '附件记录',
    component: 'annex',
  },
  {
    key: '14',
    tab: '更新记录',
    component: 'updateRecords',
  },
];
//查询条件
export function getFormConfig(): Partial<FormProps> {
  return {
    labelWidth: 100,
    schemas: [
      {
        field: 'givenYear',
        label: '填报年份',
        component: 'DatePicker',
        componentProps: {
          placeholder: '选择填报周期',
          picker: 'year',
          valueFormat: 'YYYY',
          format: 'YYYY',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        field: 'quarter',
        label: '填报季度',
        component: 'Select',
        componentProps: {
          options: [
            { label: '第一季度', value: '第一季度' },
            { label: '第二季度', value: '第二季度' },
            {
              label: '第三季度',
              value: '第三季度',
            },
            {
              label: '第四季度',
              value: '第四季度',
            },
          ],
          placeholder: '季度',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '立项投资额',
        field: 'projectInvestment',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '资金来源',
        field: 'fundingSource',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标方式',
        field: 'biddingMethod',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '建委招标',
              value: '1',
            },
            {
              label: '平台招标',
              value: '2',
            },
            {
              label: '邀标比选',
              value: '3',
            },
            {
              label: '直接委托',
              value: '4',
            },
            {
              label: '评分定离',
              value: '5',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '合同类型',
        field: 'contracYpe',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '施工',
              value: '1',
            },
            {
              label: '监理',
              value: '2',
            },
            {
              label: '设计',
              value: '3',
            },
            {
              label: '图审',
              value: '4',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '合同名称',
        field: 'contractName',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '甲方单位名称',
        field: 'firstPartyName',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '乙方单位名称',
        field: 'secondPartyName',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '合同形式',
        field: 'formOfContract',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '固定总价',
              value: '1',
            },
            {
              label: '固定单价',
              value: '2',
            },
            {
              label: '费率',
              value: '3',
            },
            {
              label: '其他',
              value: '4',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '合同签订时间',
        field: 'contractSigningTime',
        labelWidth: '140px',
        component: 'DatePicker',
        componentProps: {
          valueFormat: 'YYYY-MM-DD',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '竣工时间',
        field: 'closingTime',
        labelWidth: '140px',
        component: 'DatePicker',
        componentProps: {
          valueFormat: 'YYYY-MM-DD',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '结算完成时间',
        field: 'closingTimeDatetime',

        labelWidth: '140px',
        component: 'DatePicker',
        componentProps: {
          valueFormat: 'YYYY-MM-DD',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '合同金额',
        field: 'contractAmount',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '签证、变更金额',
        field: 'submittedForSettlement',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '结算报送金额',
        field: 'superContractScale',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '结算审定金额',
        field: 'sumOfMoney',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '结算审核金额超合同额比例',
        field: 'proportionContractAmount',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '会议纪要',
        field: 'meetingMinutes',
        labelWidth: '140px',

        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '备注',
        field: 'remark',
        labelWidth: '140px',

        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
    ],
  };
}
