import { BasicColumn, FormSchema } from '@/components/Table';
import { useUserStore } from '@/store/modules/user';

const deptId = useUserStore().userInfo.deptParentId;
//主模块-招标计划列表页
export const columns: BasicColumn[] = [
  {
    title: '序号',
    dataIndex: 'serialNumber',
    width: 100,
  },
  {
    title: '填报周期',
    dataIndex: 'tenderYear',
    width: 200,
  },
  {
    title: '项目数量',
    dataIndex: 'proNumber',
    width: 180,
  },
  {
    title: '公司名称',
    dataIndex: 'companyName',
    width: 180,
  },
  {
    title: '最新更新人',
    dataIndex: 'updateBy',
    width: 180,
  },
  {
    title: '审核状态',
    dataIndex: 'reviewStatus',
    ifShow: deptId != '100',
    width: 140,
  },
  {
    title: '审核人',
    dataIndex: 'revieweUser',
    width: 180,
  },
  {
    title: '审核时间',
    dataIndex: 'reviewTime',
    width: 180,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'tenderYear',
    label: '',
    component: 'DatePicker',
    componentProps: {
      placeholder: '年份',
      picker: 'year',
      valueFormat: 'YYYY',
      format: 'YYYY',
      style: {
        width: '100%',
      },
    },
    colProps: { span: 4 },
  },
  {
    field: 'companyId',
    label: '',
    component: 'Select',
    componentProps: {
      placeholder: '公司名称',
      options: [
        {
          label: '公司名称',
          value: '公司名称',
        },
      ],
    },
    colProps: { span: 4 },
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'proName',
    label: '项目名称',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'fundingSource',
    label: '资金来源',
    required: true,
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'projectInitiator',
    label: '立项主体',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'investmentAmount',
    label: '立项投资额',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'biddingType',
    label: '招标类型(施工、监理、设计、图审等)',
    required: true,
    component: 'Input',
    colProps: { span: 7, offset: 1 },
    labelWidth: 400,
  },
  {
    field: 'controlPrice',
    label: '预计控制价',
    required: true,
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    field: 'plannedPeriod',
    label: '计划工期',
    required: true,
    component: 'RangePicker',
    colProps: { span: 7, offset: 1 },
    componentProps: {
      valueFormat: 'YYYY/MM/DD',
      format: 'YYYY/MM/DD',
    },
  },
  {
    field: 'biddingPeriod',
    label: '计划招标周期',
    required: true,
    component: 'RangePicker',
    colProps: { span: 7, offset: 1 },
    componentProps: {
      valueFormat: 'YYYY/MM/DD',
      format: 'YYYY/MM/DD',
    },
  },
  {
    field: 'biddingMethod',
    label: '招标方式',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '建委招标',
          value: '建委招标',
        },
        {
          label: '平台招标',
          value: '平台招标',
        },
        {
          label: '邀标比选',
          value: '邀标比选',
        },
        {
          label: '直接委托',
          value: '直接委托',
        },
        {
          label: '评定分离',
          value: '评定分离',
        },
      ],
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    label: '招标内容',
    field: 'tenderContent',
    required: true,
    component: 'InputTextArea',
    componentProps: {
      maxlength: 100,
      showCount: true,
    },
    colProps: { span: 7, offset: 1 },
  },
  {
    label: '备注',
    field: 'remark',
    // required: true,
    component: 'InputTextArea',
    componentProps: {
      maxlength: 100,
      showCount: true,
    },
    colProps: { span: 7, offset: 1 },
  },
];
